import random


def randomUuid() -> str:
    """
    生成随机的uuid
    :return: 随机的uuid
    """
    import uuid
    return str(uuid.uuid3(uuid.uuid4(), str(uuid.uuid1())))


def randomInt(start: int = 0, end: int = 100, step=None) -> int:
    """
    随机生成指定范围内的整数
    :param start: 开始范围
    :param end: 结束范围
    :param step: 步长
    :return: 随机整数
    """
    if step:
        return random.randrange(start, end, step)
    return random.randint(start, end)


def randomFloat(start: float = 0, end: float = 1, scale=None) -> float:
    """
    随机生成指定范围内的浮点数
    :param start: 开始范围
    :param end: 结束范围
    :param scale: 精度
    :return:
    """
    if scale and scale > 0:
        return round(random.uniform(start, end), scale)
    return random.uniform(start, end)


def randomBool() -> bool:
    """
    随机一个bool值
    :return:
    """
    return randomFloat() > 0.5


def randomItem(items: (list, set, tuple, str)):
    """
    随机一个元素
    :param items: 元素集合
    :return: 随机一个元素
    """
    if items:
        return random.choice(items)


def randomItems(items: (list, set, tuple, str), size=1, distinct=False) -> list:
    """
    随机一个元素列表
    :param items: 元素集合
    :param size: 随机个数
    :param distinct: 是否去重
    :return: 随机元素列表
    """
    if items:
        if distinct:
            items = list(set(items))
            if 0 < size == len(items):
                random.shuffle(items)
                return items
            if 0 < size < len(items):
                lists = []
                while len(lists) < size:
                    it = random.choice(items)
                    if not lists.__contains__(it):
                        lists.append(it)
                return lists
            else:
                raise RuntimeError("distinct item len < random size")
        else:
            if size > 0:
                lists = []
                while len(lists) < size:
                    lists.append(random.choice(items))
                return lists


def randomChars(size: int, distinct=False) -> str:
    """
    随机生成指定长度的可见字符串
    :param size:
    :param distinct:
    :return:
    """
    items = []
    items.extend(range(48, 57))
    items.extend(range(65, 90))
    items.extend(range(97, 122))
    random.shuffle(items)
    rItems = randomItems(items, size, distinct)
    return "".join([chr(item) for item in rItems])

def randomAlphabet(size: int, upper=False, lower=False, distinct=False) -> str:
    """
    随机生成指定长度的可见字符串
    :param size:
    :param distinct:
    :return:
    """
    items = []
    items.extend(range(65, 90))
    items.extend(range(97, 122))
    random.shuffle(items)
    rItems = randomItems(items, size, distinct)
    randomStr = "".join([chr(item) for item in rItems])
    if upper:
        return randomStr.upper()
    if lower:
        return randomStr.lower()
    return randomStr

def randomNumberStr(size: int, distinct=False) -> str:
    """
    随机生成指定长度的数字字符串
    :param size:
    :param distinct:
    :return:
    """
    items = []
    items.extend(range(0, 10))
    random.shuffle(items)
    rItems = randomItems(items, size, distinct)
    return "".join([str(item) for item in rItems])


def randomMobile(*pres) -> str:
    """
    随机生成手机号
        randomMobile(180,136,185)
    :param pres:手机号前缀
    :return: 手机号码
    """
    preStr = "1"
    if pres:
        preStr = str(randomItem(pres))
    randomSize = 11 - len(preStr)
    if randomSize > 0:
        return preStr + "".join(randomItems("0123456789", randomSize))
    else:
        return preStr[0:11]


def randomMobiles(*pres, size: int = 1) -> list[str]:
    """
    随机生成一批手机号
        randomMobiles(180,136,185, size=10)
    :param pres:手机号前缀
    :param size:批量大小
    :return: 手机号码
    """
    mobiles = set()
    if size <= 0:
        return []
    while len(mobiles) < size:
        mobiles.add(randomMobile(*pres))
    return list(mobiles)


class NameCreator(object):
    def __init__(self):
        nameStr = "赵,钱,孙,李,周,吴,郑,王,冯,陈,褚,卫,蒋,沈,韩,杨,朱,秦,尤,许,何,吕,施,张,孔,曹,严,华,金,魏,陶,姜,戚,谢,邹,喻,柏,水,窦,章,云,苏,潘,葛,奚,范,彭,郎,鲁," \
                  "韦,昌,马,苗,凤,花,方,俞,任,袁,柳,酆,鲍,史,唐,费,廉,岑,薛,雷,贺,倪,汤,滕,殷,罗,毕,郝,邬,安,常,乐,于,时,傅,皮,卞,齐,康,伍,余,元,卜,顾,孟,平,黄,和,穆," \
                  "萧,尹,姚,邵,湛,汪,祁,毛,禹,狄,米,贝,明,臧,计,伏,成,戴,谈,宋,茅,庞,熊,纪,舒,屈,项,祝,董,梁,杜,阮,蓝,闵,席,季,麻,强,贾,路,娄,危,江,童,颜,郭,梅,盛,林," \
                  "刁,锺,徐,丘,骆,高,夏,蔡,田,樊,胡,凌,霍,虞,万,支,柯,昝,管,卢,莫,经,房,裘,缪,干,解,应,宗,丁,宣,贲,邓,郁,单,杭,洪,包,诸,左,石,崔,吉,钮,龚,程,嵇,邢,滑," \
                  "裴,陆,荣,翁,荀,羊,於,惠,甄,麹,家,封,芮,羿,储,靳,汲,邴,糜,松,井,段,富,巫,乌,焦,巴,弓,牧,隗,山,谷,车,侯,宓,蓬,全,郗,班,仰,秋,仲,伊,宫,甯,仇,栾,暴,甘," \
                  "钭,厉,戎,祖,武,符,刘,景,詹,束,龙,叶,幸,司,韶,郜,黎,蓟,薄,印,宿,白,怀,蒲,邰,从,鄂,索,咸,籍,赖,卓,蔺,屠,蒙,池,乔,阴,鬱,胥,能,苍,双,闻,莘,党,翟,谭,贡," \
                  "劳,逄,姬,申,扶,堵,冉,宰,郦,雍,郤,璩,桑,桂,濮,牛,寿,通,边,扈,燕,冀,郏,浦,尚,农,温,别,庄,晏,柴,瞿,阎,充,慕,连,茹,习,宦,艾,鱼,容,向,古,易,慎,戈,廖,庾," \
                  "终,暨,居,衡,步,都,耿,满,弘,匡,国,文,寇,广,禄,阙,东,欧,殳,沃,利,蔚,越,夔,隆,师,巩,厍,聂,晁,勾,敖,融,冷,訾,辛,阚,那,简,饶,空,曾,毋,沙,乜,养,鞠,须,丰," \
                  "巢,关,蒯,相,查,后,荆,红,游,竺,权,逯,盖,益,桓,公,万俟,司马,上官,欧阳,夏侯,诸葛,闻人,东方,赫连,皇甫,尉迟,公羊,澹台,公冶,宗政,濮阳,淳于,单于,太叔,申屠,公孙,仲孙," \
                  "轩辕,令狐,锺离,宇文,长孙,慕容,鲜于,闾丘,司徒,司空,亓官,司寇,仉,督,子车,颛孙,端木,巫马,公西,漆雕,乐正,壤驷,公良,拓跋,夹谷,宰父,穀梁,晋,楚,闫,法,汝,鄢,涂,钦,段干," \
                  "百里,东郭,南门,呼延,归海,羊舌,微生,岳,帅,缑,亢,况,後,有,琴,梁丘,左丘,东门,西门,商,牟,佘,佴,伯,赏,南宫,墨,哈,谯,笪,年,爱,阳,佟,第五,言,福 "
        bodyNameStr = "壮,昱杰,开虎,叶行,家越,煜文,家惟,龄之,俊有,啸威,浩一,向红,军,建荣,紫威,彬,作为,博轩,爵,榕轩,韦聿,仁腾,诏涣,勇宁,东阁,泰寰,春军,翼帆,诏炀,培帆,又淇,谦韵," \
                      "子柏,永慧,仲泉,恒一,恒源,凯,大奇,兴宁,笑野,浩峰,宪,伟平,彦博,树魏,坚武,梓华,啸吟,华繁,啸宇,健奇,艺臣,一同,疾风,伟洪,镜敏,政浩,子旭,玉轩,子林,延赤,禾,环球," \
                      "亚韬,昊俊,嘉汶,纯德,天宇,盛世,华山,兆临,泽光,栗,樯,一辉,闻博,国洋,毅杰,建可,惠山,谦之,连喜,溪俨,学江,树鹏,鹏,天友,庆宇,本凤,少涛,键程,厚霖,泽一,清嵘,车亦," \
                      "新民,志东,剑清,海霖,一溪,融渝,玺剑,超宇,永润,人月,炳荣,冰博,季栋,仁赫,兰斌,嘉伟,军军,鄂,思华,建青,兴华,冀川,赞平,佳汛,万鹏,飞平,树隶,子桁,志忠,柯茗,佛晓," \
                      "之帆,晟尔,守均,茁壮,梁宇,博洪,亚军,翼成,胜轩,子皿,记博,博玉,继优,翰琨,均培,敦强,浩羽,先登,明津,潇添,燃,章见,本三,仁甫,小磊,文福,鹏云,成虎,家正,来麟,树木," \
                      "超勇,榀荃,博涛,炳越,宝全,浩然,明华,士琪,自逊,风力,世玉,文禹,付增,戊石,天麟,新宇,彭弘,玉松,绍优,熹伟,才铭,以优,丰,文丁,凯菱,霆,禹萌,唯,建捷,韦仅,立安,星博," \
                      "文誉,洛漾,丰翌,心我,榛元,承乐,运晟,霆锋,明鉴,宝愈,国宇,维稼,乐玺,二,张钰,柏晨,铱,尊,晓斌,益思,敬敏,艺怊,嘉增,栋良,棁,家宇,思宜,恩昊,逸鹤,雍颐,光煜,智怡," \
                      "培治,涛远,东东,文舆,怿,健民,如意,万昆,腾中,明德,铨坤,招,道军,书畅,万祥,名川,雨沛,英钧,禹诚,湘溢,咏壹,丁翱,志虎,黎烘,艺言,照临,泓敖,志男,赫名,传金,晖涵,轩齐," \
                      "启宇,韬淘,熙恒,渡,晓戈,兆均,旭九,能嘉,佳尧,天松,毛瘩,胜尧,米黄,福伦,林烨,邦鑫,奕臣,会军,泽江,云辉,志皓,之烨,焕起,逸宁,庆国,晏霆,桡铭,子地,家辉,鹏飞,辉煌," \
                      "于瑞,梓棕,中彦,锦尧,福昌,辛戎,寰宇,家雨,立刚,城石,侦烨,记政,威新,润兵,天添,磐石,礼发,苏联,一豪,义彪,霄,再熠,于皙,嘉韬,胜群,宝同,一了,冠毅,红中,宇捷,卿,政昊," \
                      "博文,培然,粲粲,昱天,一铄,廷,丁,西成,茂赓,克帅,惠达,世洲,郁安,振舫,三瑞,哲昱,源源,云起,吉尔,黎鑫,鳅锋,钰满,致辉,培海,立华,灿昕,新颜,子灏,京辉,晋尧,争,逸舟," \
                      "镐,小峰,择石,吾行,天硕,宇飞,钧哲,睿,恺越,锦彦,子豫,绅缘,力飞,昊坤,紫昊,雨凡,生诩,黎泓,方欣,大帝,青,奕融,博松,士海,煜烽,柏铎,晋,誉皓,献军,鸿儒,家维,晨旭," \
                      "发全,松俊,厚林,若帆,匀浩,广明,甫元,本烽,水泉,天赐,士红,更航,汉涛,纬,相淇,渊龙,近任,彦钧,铄,易磊,雏腾,步财,力帆,先智,岩,畦嵘,之恒,霈焱,文相,诚之,临渊,嘉靖," \
                      "昊鑫,宇辰,锶齐,育博,忠泽,国文,绎皓,晏玮,丁予,晖,大兴,恒翡,元八,学军,尚印,立志,绍友,献林,永生,军旗,亚,泳嘉,云岩,宏敏,倍林,煜濮,又元,颢继,志博,子晟,哲骞,洪贤," \
                      "思危,学斌,新平,驰云,泽峰,耀明,竟凯,天彤,钰文,国权,健深,家瑜,大伟,丞,前坤,志洋,世强,颖军,支聿,栋宇,子尘,缘博,卫,仁东,现春,保建,丞扬,禹宣,嘉恒,明翰,昊军,飞仰," \
                      "煊,弛,志豪,世智,文祥,嘉骐,镇,晓龙,盛名,晋嘉,允,鸣哲,思锐,子宏,效金,恪震,稼,文程,树文,天意,金勇,义山,卫东,富仪,国威,泯柱,羲峰,元三,明章,玮新,鼎余,新立,旭飞," \
                      "冠发,子钱,玉峰,晨硕,智杰,跃明,东森,薪扬,俊宝,宝强,敬宁,钰竣,润,梓城,冰溢,艺洋,柏言,一涵,国维,学而,子彧,晓皓,增,杰,明顼,渝,家一,振中,阗田,伟,钰逵,晶皓,泺杰," \
                      "晟之,孟利,维,宏康,兴云,奭彧,新昊,华良,应腾,晋坤,泉景,益玮,偌石,曦恒,德,博武,陆鑫,耀崎,志民,泓轩,家祺,勇搏,莘源,永进,子源,山,乐轩,帆,文斌,长鑫,修铭,罡毅," \
                      "火根,金朱,熹远,子鼎,鸿羽,鸿峰,贺迪,伟明,引平,财茂,深泉,储剑,己辉,振东,偲齐,劲杉,垒,风宝,泽众,宇军,仲源,彦乐,鸿义,新悦,哓翕,旭军,保真,会勇,永红,建安,天烘," \
                      "金忠,祎藤,自鸣,志超,立荣,逸清,多旭,大采,必杰,承智,岭楠,锦伟,忆罗,亚辉,剑锋,子鹰,稿,玮霁,轶铭,宏民,悟石,奔,鑫田,书行,寒峻,伟东,云驰,新钧,时立,润和,裕,彦," \
                      "子珩,荐程,嘉政,昕源,畦尧,祖东,雨卓,潍,志琪,涵博,乐平,浩坤,厚郴,俊熙,进,新忠,绍涵,震天,哲力,峻,明军,沛帆,志朋,无悔,煜燊,剑飞,开宇,韶荨,民成,子岩,健,棋西,程," \
                      "云杰,皓坤,为民,耀建,成伟,翊程,宏谟,叮咚,泳杰,儒绅,锦浩,柽锘,达,子忱,晓旭,伯伟,雄霸,怀民,豫,本祯,月东,永菜,洲,宁,霄城,钰润,宇佳,瑞林,树勋,永圯,中芏,生明," \
                      "霄龙,臻安,维强,亦多,文启,艺逞,宗寿,勇刚,佳祥,怀仁,家祥,柯言,若熙,立东,付华,光宇,文靖,康,熹玮,联博,志勇,子千,泽辉,雍仪,新源,忱,彦文,裕淼,阳阳,一鸣,天琪,晓垒," \
                      "国庆,建华,搏涵,越羲,子辰,瀚为,峻逸,昀天,全心,铭浩,云,浩成,建明,新文,闻涛,中进,印螺,思胤,子才,哲栋,小霄,永利,子宣,抱石,平宁,依贻,永兴,华彬,匡胤,焕军,会初," \
                      "文俨,银全,禹然,付荣,小龙,泉盛,黎弘,文行,煜恒,力玮,清满,怀荣,永波,炳珲,光雷,建珂,江立,记策,佳洲,英策,旭君,韦迪,子欣,贤文,鹏远,子丞,梓希,霖,泽生,永淇,文铧," \
                      "广勇,呈,力苇,颢,晓生,大国,绍教,焙,渝川,尧,厚相,崇,偲煜,恩,扬,致墚,桐瑞,宜帆,辉华,易恒,盟潞,刘一,诚诚,欣煜,子骐,学海,烙豪,子震,智友,智永,志鸣,小文,李杰," \
                      "艺什,均伟,宝良,俊男,选军,文振,禹森,靖玮,哲轩,健程,毅轩,守君,子良,寅,柏泽,之琰,子竞,言,绍珺,鑫哲,亚鹏,海根,树楷,榄,义杨,佳腾,晨帅,奕宁,岩松,艺明,悦阳,名," \
                      "本安,雨晨,吾稷,诣修,子信,广修,禹函,方方,新新,天舒,鹏智,议麦,子峰,品桦,致,钰昆,智敏,碧宝,子安,卞聿,子腾,黎宏,民琦,安琪,国旭,西俊,志乔,元一,瑞俊,隆,良枝,源荣," \
                      "东,丰文,厚彬,厚楚,儒祥,铁军,天玄,津川,国辉,子弘,宏海,嘉贤,恒欣,纯烨,晓涛,建国,嘉诚,斌宇,鸿潍,懿良,路,勃,永锋,钊,毅瑞,树岗,卓羲,子太,聿珂,林峰,煜铠,传昌," \
                      "旷元,子恩,焱年,妙丰,俊皓,泽元,连仲,跖,孙侃,靖,为正,子钦,傲立,元五,锷,东明,诩,大圣,烁贻,煜熙,译文,占环,梓言,西雷,长凇,志玮,临旭,延波,竞博,沩,庆威,元聿,琦逸," \
                      "宏韦,俊峻,可东,宝玉,烨之,烨明,鹏博,亦尘,泽之,子琛,之涣,砚,天鹏,思谐,浩震,学宁,戈雷,思愚,子亮,启,贵有,嘉牧,有科,沛淮,礼义,轶文,铄海,宇钦,俊彦,焯楷,森东,文起," \
                      "琪逸,玉忠,波,闵柱,锐柏,鸿敏,旌任,贝宠,继龙,子熙,天田,秋廷,凯瑞,首钧,书瀚,钽轶,立新,志文,华君,综融,湘汝,恒宽,平峡,轩海,书玉,屹玮,常明,昊,雨童,福胜,鲑埔,佳明," \
                      "丁元,迄,文志,红兵,志威,宪军,庆军,凡玄,桂超,明红,如昕,玄峰,惟,北北,新雨,巍,保刚,鼎天,国正,步高,鑫源,淼淼,太阳,叶宣,本艇,财明,贝聿,煜钢,君平,方成,秦,心砚," \
                      "安勇,醇烨,誉怀,得亮,广嘉,立宏,紫腾,炬,联锋,占波,劲,梓洋,文俊,霈然,毅剀,海宾,洪君,顺娃,国沧,大大,树立,腾辉,语宇,务石,钰坤,剑柯,志锁,普加,亚伟,彬杰,荐成,相龙," \
                      "诗泽,晨洋,玉胜,崇岳,鼎民,兴疆,嘉福,玮珀,飞帅,士杰,笑山,盟坷,官全,星昊,天依,同安,天俞,均炜,启越,子赫,彦淮,允禄,翰宇,遭,本亮,乙征,三奔,燮林,经程,天骥,值浩,滔," \
                      "万海,宇晨,寒骏,师心,小凯,飞麟,中锴,凯聆,金铢,勤,利军,昌盛,庆,建志,龠曦,宇,朕,长鸣,淳烨,桂鸣,育栋,小,嘉喜,延龙,韦稼,岩郊,心念,文廷,梓俨,鹏宇,建谨,灿,宇恒," \
                      "颐轩,为为,栀荣,梓烨,礽宠,鼓腾,涵一,传艮,伟新,锶铭,坤澎,宽巧,富强,新路,鳅渔,舒同,天问,心宝,彦恺,晋中,勤元,继之,梓成,全,昭炀,言郊,清栋,吉平,开石,华臣,博虎," \
                      "学汉,仁,海波,鹤,铭桐,永屹,轩鸣,泓扬,铭学,博宇,进兴,德军,禹暄,田,家宝,晋帷,成梓,宏潍,友碧,景博,大琦,清荣,雪中,万里,钦,一庭,溯溯,大勇,承,化忠,京津,鑫磊,加乐," \
                      "培玉,启策,正刚,柯涵,辛昊,安各,志会,钊恒,令锋,烁,全昆,成科,天国,树威,鲁愚,伯虎,诩生,文哲,赢文,崇楦,铁成,金波,文海,梓平,旭敏,铎海,顺利,鸿维,润军,铭轶,洪川,灼," \
                      "金城,才恒,鼎弘,孚融,东博,文林,梯烨,旺旺,焱宁,衍昀,义芝,神,泸,国荣,康宁,世伟,家连,跃建,建平,渝淇,科州,凌博,立明,柽铭,乐瑞,恒铭,记昀,速捷,宏维,涵文,吾光,云轩," \
                      "俊入,义,锁川,寄平,丁曦,国明,文栋,纪苏,成昊,广玉,四昱,光强,晨扬,奕炜,一晗,金梁,明勇,钰澄,飞,伟鹰,李谊,晓翰,浚,世平,爱国,安铃,雪酉,大峰,鸣世,文霖,德志,竟胜," \
                      "泺漾,伟铭,欣汝,玉斌,钟海,崤龙,思言,育恒,慧来,亚峰,墨然,烁桐,爱民,浩智,桂柱,张晨,赫明,立群,程枫,皞晖,怀东,珉柱,烜,献武,瑞华,禧贤,子育,皓文,博林,红涛,源太," \
                      "绍军,野,璨,金迟,悦边,伟力,羽其,昭,文双,书兵,广同,宏儒,书航,开华,恒德,会光,延岭,元七,贺僮,博思,友恒,士铭,赫铭,子鉴,子天,郝宇,天榆,昊泽,旺牛,思博,国全,洪勋," \
                      "南星,纪超,一闻,剑峰,赢,子鹏,海澎,振胜,厚哲,恒薪,时予,黄米,良缘,树彪,冠玉,振宜,野夫,占华,楚一,瑜涛,茗辉,仁秋,福山,文青,宝国,道能,晓明,云贵,嘉尧,宝贤,友仅," \
                      "添锦,曦,钧崴,永杰,稳锋,与彦,治铭,宏卫,彦民,逸飞,云天,仁会,沛之,吾航,茗柱,问谨,学潼,旭彤,炳超,少江,子狄,浩雄,冰剀,应彬,树伟,天福,雨辰,挺,广,懿轩,岭南,毅," \
                      "建成,效忠,瑞,吉根,盛利,世泽,仪宇,浩权,璞煜,艺桥,常鸣,伟林,锌轩,齐恺,其明,玉文,思洗,亚斌,泰钧,亚伦,宗羲,锃,铭钐,皓元,戟,一宁,彬洲,子翔,朝府,佛霆,无极,用颐," \
                      "建龙,志强,子晨,见波,鹏珂,全琨,胤燃,高雅,跃,蛟蛟,煜轶,学奇,胤贤,柏慧,传奇,泽云,永熠,恺稷,祖寿,海涛,敏沣,泽林,稽,杰成,天鸿,宣辰,涛,文骐,建飞,战平,文滔,熙宇," \
                      "汉翀,浩骅,浩晟,华桥,建基,本初,天昀,杰俊,杨又,凯怡,鸿艺,屹森,琭珧,晨晖,淏轩,旭阳,荣荣,鸿基,雨杰,振铭,忠雷,天玉,河征,则石,振明,东梁,小才,玺宇,志为,德胜,树廷," \
                      "子清,佳程,辛宇,宇欣,银发,有祥,文府,学峰,建深,栗源,科淇,宇帅,夕优,台,心均,家荣,本强,孟勇,天烁,建方,国敏,子封,嘉生,艳强,尔丰,荃坤,晏瑞,今朱,荣德,埔铖,子聪," \
                      "文敬,子琦,光辉,白卓,子宬,耀哲,财华,庆友,聪宇,朝蓬,宁仁,荣达,子桀,烁哲,安戈,无克,锐哲,旺,晓珲,征,树辉,祚誉,海洲,诏,辰若,熔石,政,易贻,君卓,晨煜,海彬,天爱," \
                      "林鹏,力,晨罡,力邦,龙泽,成振,世升,名琛,克豪,洛嘉,梓源,元九,启丞,天齐,勒,新会,林霄,新刚,松康,昱升,楚煊,福宣,家伟,雨龙,皓,晟铭,艺巩,锫帆,永辉,明浩,拓,崇俊," \
                      "可欣,邵敏,荣华,燕鹏,可光,信崴,逸吉,明刚,寓原,晓凡,泉宇,久彬,欣圣,科晴,殿红,煜铭,一廷,洛,文力,睿扬,水欣,广军,占龙,水莘,剑,鸣,余荣,圆源,善宏,连华,紫豪,彦锦," \
                      "祥刚,讯谟,屿,球,桓铭,云州,奕卿,淇尔,建博,淋,述平,文玄,新国,灵博,思凡,厚湘,冰汝,晨阳,元二,惠宣,九龄,雷,泉,杉,悦鑫,墨晗,紫翰,爱新,天龙,力铭,梓研,钊华,沛晟," \
                      "禹轩,竞锐,若石,宜程,沛天,添,瀚文,胜,思渐,常入,超,民柱,瑞希,天辉,成刚,浩斌,与,筌贰,仕海,林宾,诗育,思彦,添易,济恺,人之,帅奕,思恒,健生,弘韬,如,铁平,嘉正,文富," \
                      "鼎凯,均,思谚,健凯,梁东,呈炜,义琛,超越,竟轩,强,海云,赞,晨祺,雨晟,治华,斯祁,文熙,浩嘉,英浩,鑫仪,耀匀,紊文,清漾,崇源,政喃,飞扬,山川,允潇,鞠国,春杰,文余,邦峰," \
                      "如稷,信孜,文昕,李承,邻溪,宇轩,佳林,赵勇,鼎愚,怀友,崴,成彪,士立,江宇,凯彦,贵元,县科,兆轩,轶震,元十,永兵,毅怊,子烨,胜玉,金华,甲辉,欣源,子昕,益波,广垒,荣,钏海," \
                      "清淞,礼维,为政,国超,云奇,胤诚,紫瀚,春天,弘力,丁天,小丁,小皓,苠柱,清哲,淘淘,伟伟,子雷,海亮,祺法,文澜,泰,利帆,仅开,若盛,成程,彪石,尉一,迦乐,雨鑫,振学,博寒," \
                      "山山,思镐,佳乐,立民,飞雄,江龙,铭峰,彬哲,福荣,彦祺,铭,希林,乾坤,越恒,德录,元乃,同举,岩石,泽华,金,硕恒,承文,正,德智,天合,春铭,新录,筹,震舫,紫炜,瑞涛,焉平," \
                      "一征,本焱,天阳,闵闵,景智,德耿,长荣,金塔,兴月,敬云,洪杰,铮海,琪亮,凤岐,天洪,子豪,释予,师禹,继耐,捷,家成,小伟,向华,建永,绰鉴,兴俊,洪涛,蔚波,火霄,正阳,开吉," \
                      "木椟,大增,必胜,大宇,艺胜,泰力,诚,海琛,韶齐,雪健,潇凯,畔,焱森,力川,杰城,豫暄,子贵,弘维,元四,玉杰,之初,淮南,禹权,智海,又辉,增沂,涵宇,达生,泽川,灿灿,保红,嘉境," \
                      "翔,喜顺,小瑞,思尧,哲文,聪欣,增荣,仁杰,杰晟,柳稳,顺敏,富平,勃松,旌宇,凌棱,众,雍,兴雨,日广,林溪,富城,杨广,一彤,永亮,武飞,利宝,恒铨,中民,笑铭,珑译,耀希,侦驰," \
                      "车羽,哲,胤然,煜玺,源,弈儒,糟,椿烨,通震,轩祐,旭星,小华,泓维,瑞杰,东海,力弘,思波,林玉,国石,云哲,尚轶,学勤,舒民,林,红东,煜权,人稼,祺恺,竞,凯明,柽铎,瀚宇,文晋," \
                      "守禄,衍,韦众,志宏,啸龙,梏,昶然,东琛,文良,瀚引,品谋,玮炜,水源,天羽,智渊,成云,天红,贺淇,志刚,家墨,起林,金石,毫晨,释之,叙淳,海,子扬,则玉,栗琛,建杰,鸿志,凌晟," \
                      "晔,柏,纤昊,勃滨,克平,禄,要攀,诏震,皓寓,孜洋,世杰,了一,宸豪,子亲,威皓,炫锋,露中,建人,达宁,泽岐,贤先,建洪,玉富,晓峰,海冰,恪铭,钰麟,奎胜,梓立,煜盛,曲坤,子昱," \
                      "浩润,嘉轩,家豪,本航,本田,宇凡,羽粲,天佑,士硕,昕宇,洪源,健树,特,子伯,厚汀,蛟,宏,浩伟,涌太,天琦,华冰,胤言,春明,江,云祥,翌轩,政皓,震坤,春龙,超刚,刘畅,振,科理," \
                      "占久,财将,高,近冬,官,凯翎,斯旗,友林,润恒,尉,腾,羲,清洋,智俊,子凡,迦勒,贺彤,轶华,俊星,焕,瑞熙,维杰,晋伟,雨亭,振宇,志儒,隆吉,嘉乐,锐,小东,自川,濂敏,李轩," \
                      "共金,永贤,靖百,腾达,田烽,鼎儒,种,学山,卫华,友清,亚涛,明雨,唯德,仅众,联全,友烨,富华,献,峻艺,祥洲,紫石,楷铭,长亦,雪山,张黄,天,余晗,忠世,志诚,文超,继承,炳文," \
                      "鸿灏,一诺,春皓,胜文,鹏举,丞含,政权,举纲,靖嘉,文庭,献文,言骄,承民,崇懿,享眠,邯,明涛,琥诚,首军,瀚,孟达,新澳,李诚,韦臣,曾刚,宜宣,家鸣,越,祁强,宏宇,维东,凡雨," \
                      "宇通,杨航,谦昊,海中,维新,怀亮,竞胜,晟烨,叶良,存吉,畦山,名柱,一峰,熙,佳伟,立杉,景波,凯仪,隽,航滔,大海,文睿,汝杰,天祥,仕杰,峰铭,思渠,志昕,午光,思渤,泽滟,芪," \
                      "永俊,一水,雪飞,洧,拙羽,兵,河江,长征,海岩,之荣,牧,飞羽,子涵,卫新,丁文,文涵,咏辉,基栋,翎西,奂奂,星宸,柽名,冲,梓伟,呈珉,壹冰,炜鹰,尔泰,龙文,吉松,荪,殊言,帅克," \
                      "闯,军伟,传君,一钰,德银,宇栋,占平,加琛,子亚,叶航,卓雨,凇,子渊,轩豪,宪君,纬新,珑,梁栋,益坚,晓东,巴聿,世恩,延年,智泽,玉一,元旦,凯昕,若钢,黎俊,傲伟,韶奇,之栋," \
                      "皕,涣晟,硕楠,蛸龙,益甫,爱军,祥雨,泽霆,嘉锡,凯杰,利安,正飞,雪涛,煜汀,华,武盾,圣群,硕,雨桐,莘田,其,楚宁,文博,泊泽,研博,官钱,洪敏,政哲,德俊,广森,岳灿,青洋,矛," \
                      "前进,建席,国生,隽巍,世缘,秉彰,林佳,玉祥,臻,逸卿,红力,艺众,泳淇,齐,明宇,子伟,兆启,恒轶,李博,筱林,繇,怡浩,庆平,亨太,海培,相茗,啸,侦仲,莜昊,笠仲,梓严,宇琨," \
                      "佳坤,元瑞,维龙,永康,钝海,铎馨,书铭,朝洋,为一,厚杳,振波,鑫铭,德利,安,辰宇,瑜生,心源,宝,竹林,智墚,森栋,凯晨,国飞,忠洁,建宁,明星,天宝,臣,新禄,若焕,策钧,辛生," \
                      "子健,艺皓,清伟,字逊,成龙,宇乐,车聿,昀程,晋文,号号,桂成,俊,青松,文明,思禹,飞雨,炯,椿雨,文兵,奇,成,庭境,隆石,用,凡子,恒,镇雄,阔,伟佳,宜靖,行,颢冰,绍赓,若辰," \
                      "天洋,兴利,禹芪,建艺,闻宇,子灵,泽皓,福胤,雪吉,博伦,天瑜,兴贤,泽瑜,耀辉,缙尧,永泉,一羲,谢书,天宁,焕平,阵,伍一,嘉誊,子孜,帅权,继忠,硕颀,嘉林,业龙,明泽,江红," \
                      "少勇,钰哲,肇明,培天,聪灿,煜田,畅鑫,思维,远理,迅崭,嘉畦,璞,安之,永以,晟恺,淇,名渊,泽鑫,乐,文宝,振鹏,政豪,德勤,昌正,贵云,立虎,骅,术祥,滨勃,佛廷,凌波,福宝," \
                      "乐杉,友田,子栩,帷,若刚,国钧,浩南,风,旺财,嘉锐,君入,彪,耀新,崇巍,禹阳,定星,笑添,立双,赞品,连科,文浩,奕晨,岷柱,章钰,辰维,骁纹,嘉庚,小兵,统元,泽俊,志杰,洪伟," \
                      "庆喜,悦洋,文新,林熙,志欣,文瑜,卜亓,宝黎,椿宇,禹,麒森,御言,春宇,贺任,梁,鹏义,怀曦,志缘,学桐,胜利,振宁,智博,子枫,丰岚,小攀,七七,建荩,威廉,啸博,明,勇阳,钧威," \
                      "海文,昱珂,树棋,增才,家宏,健声,本升,君麟,文亮,锡康,岩平,攀锋,昱承,禹诺,记福,凌林,明成,韵锡,田丰,亦溪,元哩,建郁,峥旭,渭,满意,红博,圳,斯文,汝杉,麒淞,安军,文楠," \
                      "怀宁,海双,夔闼,奋仁,俊安,智稼,宏建,恒通,利国,弈舟,禹芩,普华,利,伟杰,抚山,珈铭,品幕,振林,宏炜,一童,羽拙,柏林,旭岩,久翔,恩石,熠桐,昊东,凯华,思进,骜,银海,槿铭," \
                      "祥俊,明松,梓杭,小康,翊暄,欣宇,凡卜,爱铭,中宝,诚程,佐英,重庆,记顺,子琪,武,子谦,杰然,吉伟,天白,义磊,惟新,双川,了,玉强,凯信,永斌,方洲,长发,可人,天弘,炫锐,富明," \
                      "俊枫 "
        girlNameStr = "小玉,蓝,琬郡,琛青,予舴,妙妙,焱诺,艺歆,芮熙,悦优,艺杨,艺惠,爱芬,含因,楚菊,佳禾,婧妗,玉容,文莉,娅雯,碧连,芊菲,宇娜,志妍,天馨,静,涵雅,辰语,瀚樱,小捧,丹丹,黎腩," \
                      "丹华,文璐,芳辉,浚丽,才霞,采嫦,梦琪,泥,映月,铱芳,馨馨,媛鑫,紫萱,玉春,韶玥,紫玉,丽静,藤娟,朵,贞,佼悦,珍宝,千叶,嘉琪,丙芳,玉琴,丽雅,影祺,潇琳,寒凝,赛,竹梅," \
                      "颜婷,靓颖,亦菲,颖萌,筵彤,岚羽,茜柔,钦玥,伊茗,嘉韵,花玲,蕤,子歌,佛瑶,云丽,彩杰,稼妮,华蓉,彦芳,笑,尹真,笑榕,语潼,雪虹,婧雯,玉菡,欣妍,佳丽,盈乐,思佳,卜鸾,建婷," \
                      "桐菲,岑,雅彦,婧颖,氏艳,舒畅,谦雅,馨文,帼玮,子鲜,惠君,成艳,言婷,美琪,轺骊,诗青,慧英,凤霞,琼也,贝,湘玉,鑫卉,巧兰,姝英,惜颖,珈,靖茹,予易,艺涟,冰竺,兰锁,菁鹤," \
                      "理微,瑛,盼望,楚含,雯舜,歆翌,迪欣,菡韵,桂芳,贵英,艺榕,跹,键蓉,歆迪,草,爱素,丽景,春笑,慧娟,玉佳,密密,译诺,雯煜,雪晴,骊莉,贝瑶,文琼,淑莲,子娇,珍瑜,水芯,晨芳," \
                      "岚爱,琳艳,冬萍,成梅,冬梅,茜茹,恬语,恬,睬嫦,珂芯,旖旎,金芝,紫凝,希颖,淑仙,亚萍,佳钰,雪冰,兆珍,冰涵,静飞,昱瑶,启玲,韵,英英,露瑶,含裴,屏,梅娥,亚卿,橼丹,琬琪," \
                      "华梅,三红,灿荧,佳颖,纯杉,春雨,碧雪,悦兮,雅星,甜甜,惠珺,润梅,雪琴,梦迪,莺罂,钰荣,悦颜,若琪,静如,可露,雅晴,淑杰,雨柔,紫佟,青桐,淑志,白茹,伟玲,肖竹,佩君,羽桐," \
                      "玉凤,宗艳,艺萍,爱佳,志玲,雪萍,筱玲,华兰,玉馨,孜萱,伶黎,雁溪,松燕,润琳,晓蜜,立英,巧灵,真希,梦凡,欣奕,婷,网娣,月露,妮娟,沁雯,岚瑛,悦辰,静妍,籽铃,淑雅,小白," \
                      "翠萍,紫桐,索菲,盈盈,巍璇,欣雨,思苏,美珍,若芸,思蓓,婷菲,娅,纯菁,昀琪,恩蕊,梓媛,晓君,闵琼,语珊,亟奕,姣平,施,彩芬,桂荣,广琴,蒙笑,晓萍,恋泯,枫栏,紫晴,德霞,雪晶," \
                      "翊含,紫楦,苓君,兆凤,文警,馨瑶,紫瑛,叶雯,温馨,婉晴,爱华,书琳,梓萱,思冉,艺潼,兰芬,卉彤,美鑫,玉兰,馨逸,伊诺,潇佳,静莎,秋凤,倩楠,奕瑶,培娟,玉霜,千菲,理薇,晨鹭," \
                      "淑景,碧莲,宝芳,雅婕,淑敏,卫芳,予晗,潇霄,丽婧,铁娟,茜榆,晓霞,月嫦,妍熙,春娥,心艳,嫘迩,智娟,羚淯,芷洁,怡嘉,雪芹,伶藜,黛媛,左婕,心羽,蕴蔷,倩可,晶淋,茵桐,悦淇," \
                      "桂榕,琇赑,姝玉,珞彤,心瑶,禹晴,怡然,杰兰,美祎,晓琳,灵宵,子怡,雅烨,迦兰,黛妤,曾弈,嘉玲,宇蔓,英兰,文珏,籽萱,仁艳,蔓茗,盈馨,吴瑾,露予,英博,紫嫱,樱,馨怡,艺苔," \
                      "海珍,瑾晶,莹爱,奕晴,航旖,馨贤,亚冰,贞如,兰同,苡露,昕玉,之菁,梅珠,雅玲,惠梅,嘉雯,溪茹,金绣,翊倩,思竹,译予,邦蓉,为艳,甜冶,语菲,湘孜,樱琼,诗妤,钰桐,玲梦,曼珂," \
                      "玥熹,思姚,韫金,鹛邡,蓉蓉,茵芝,芝君,娇宁,玺露,肖冰,琼,敏捷,家媛,少虹,轶芳,珏媚,朝娣,晓雨,菲箐,若诗,惠娴,艺越,伶利,姝雅,荠蔚,婧宇,洁莹,梅玲,婷恣,雅莉,紫贤," \
                      "思蕊,星月,开梅,籍丹,筵栖,思冰,稼婷,琴,邦婕,婧菡,琪雨,瑞琪,黎楠,易含,翠雅,馨妍,滢滢,一枚,正英,淑贞,邦雯,佃芳,茜颖,田妮,铃,瑞凤,艳洁,琬悦,骊元,霈雨,加姿,海晶," \
                      "栩园,紫欣,立静,雯絮,苏菲,梓钥,晏佳,茉然,锦鸽,羽晴,悦茜,元圆,渔雪,俊琴,思霞,利花,雨朦,栩圆,玲芬,兰军,留霞,若嘉,睛,弈盈,邦莎,钰荥,珏欢,沂蓉,瑛琪,婉,冬琦,寒微," \
                      "畦芎,如怡,思斯,朱琴,绽雪,文琴,欣,新雅,剑萍,蔓泽,新慧,琳翊,籽妙,君蕊,诗雨,韵琳,青春,芳,亚欣,盼兮,晓钰,思琰,巧稚,芸,缠曦,丁丹,蕾镭,艳霞,小雨,东玲,讳隽,瑜茜," \
                      "美荣,六梅,婕宇,沁彤,风青,欣桐,美媛,树燕,昱芊,彩霞,岚昀,紫雯,小羽,灵儿,芬芬,烨涵,雨楠,宵蕙,维香,映荷,毓萱,艺囝,艳娇,筵蕊,雨菡,新菊,王菲,静男,雪岩,斯诺,向娟," \
                      "子璇,语墨,颐雯,珂欣,辰颖,静玉,沁范,海艳,晓洁,煜萍,甜茜,珺莉,姝雯,伊瑶,婧璇,翊茹,可涵,萩薇,梓妙,瑞菊,依彤,巧,妤芊,玟琳,夏月,润眉,影,正美,娅琳,靖菲,喻露,馨茹," \
                      "心如,颖桦,珊妹,悦然,黎娜,盈羽,晋玥,漫霓,渫晴,滢茔,浣西,欣羽,真茜,紫梓,一媛,程茵,宇馨,梦玲,娅冰,逸舒,文萍,斯琴,景红,清梅,月英,翕颖,翠英,梓丽,冰蕊,楚函,绚海," \
                      "晓雪,彦茹,慧慧,馨辰,楚依,婉合,占莉,立琴,亚莉,荧,蒙萌,蔓辰,婷曦,玲平,子琼,倩怡,当当,雯耀,雯佳,鹳央,雅淇,凤茹,沁帆,若嫣,梓伊,琫晖,茄霖,钰淼,湘匀,菁胭,虹,运蓉," \
                      "囡囡,保玲,淑璇,若思,佳榕,卓茜,晓瑞,聪洁,婉仪,筵朋,珏悦,潇颖,湉蕊,静江,玉莹,韵菡,茵彤,舒彤,可盈,秀丽,伶俐,慧郡,静柔,若羽,冰茜,旭姻,淑,舆敏,译月,桂卿,冰芳," \
                      "邦丽,舒雅,沁菲,玥,馨予,容琨,娇娇,令菲,伶,宝英,迎婷,英坤,懿珈,靖晴,萍华,安霞,才梅,艺含,梦杰,美月,远芳,诗雅,宁娟,静芳,曾伊,唤清,洽恰,屿彤,诗毓,宇璐,海媚,昱丹," \
                      "晓菁,露壬,田甜,盼希,王丽,桂芬,诺焱,蔓菱,璇玥,桂洋,巧芸,紫韩,真儿,素君,静怡,心悦,歆月,乐薇,予馨,茔茔,婉萍,予涵,奕涵,思昀,静伟,小阅,璐桢,靖悦,雨诺,小雯,晓燕," \
                      "梦娜,微茹,奕凤,琇,金涵,艳敏,含汶,迎瑕,亦雯,清妍,紫,铃铃,欣甜,肇娟,乙黛,运丽,嘉伊,翊筠,欣欣,向静,静琰,玥淼,新萍,梦兰,智晴,俊婷,艳诚,荔,虹烨,雪境,家兰,蜜蜜," \
                      "冬英,桂娇,千艳,荟君,洁宁,慕白,荟筠,建珍,謦,洪侠,雨婕,妍,茗蕊,尹,春柳,丽蓉,力香,祎甜,小燕,冰瑶,美美,世娟,雨珂,雨蒙,馨媛,娃娃,杰婷,佳瑜,巧韵,香菏,斐禾,梓茜," \
                      "雅馨,晓曦,智雅,格筵,慧仪,景梅,海英,佳琪,付燕,馨笛,紫奕,思菁,彩画,沅梦,纳文,书韵,箬晗,妃妃,洁,昀萱,雅文,笑宁,丁丽,弈雯,婉钧,小思,育娜,晓萁,春菲,惜源,玉雪," \
                      "楚洁,一玫,铄滢,雪颖,聪丽,鑫雅,美秀,茗寒,心心,忆如,梓萌,妁,雪媛,琳鑫,娟鹏,子媛,文瑛,潇涵,婵,丽岚,美茜,静琳,怡欢,威茹,笑函,真萍,苗亦,丹,岑茵,聆可,梅香,筵冬," \
                      "珈影,彩文,海雯,艳飞,曦颖,应琴,偌菡,俊芳,彦颇,祈蓝,彦妍,金露,立玲,县丽,培芳,采薇,倩倩,玲华,英,海红,珺娴,怡雯,改玲,艺童,燕婷,孟雪,海珠,心迪,洪丽,于影,昕予," \
                      "以琳,瑞婕,姝月,黍洁,薰今,东曼,雨琪,语佟,林露,燕萍,唯玮,淑茗,惠华,鸿燕,雯辉,金莲,乙靓,桂红,雅静,娜瑛,妍嘉,乃琚,丽淑,静嫣,语心,沁,家姿,爱宁,梦海,彩芳,纤亦,栏," \
                      "凤珍,淖翔,红梅,雪儿,春红,兰颖,军霞,姿,雯予,莉芬,嘉玉,玉英,艳焱,雅琪,巧瑛,蒽诺,临芳,秀利,凤焉,贻茜,玮环,香涵,米,洳洳,玉,洁鑫,玉童,静菡,语,芷晴,惠圆,欣如,珺," \
                      "烨菲,茜,延婷,婧琦,熠绮,颖,径盈,舒然,书悦,丹熠,珂馨,义琴,思沫,一晴,又丹,歆桐,斯研,纳,苏颖,韵雅,靖雯,惠颖,璐祺,惠郡,心歌,雅真,喜兰,竹莎,予敏,烟雨,荔荔,涵凝," \
                      "琬迪,如思,晓艺,娜祺,季语,珈乐,潇湉,俊婕,尤玥,玉涵,俊娴,美玉,妤亭,红琴,葭,艾琪,莺,智瑶,萧尹,丽丽,曾泓,依涵,冰凝,梅英,雅儒,妍溪,新颖,丽荣,楠钰,丹其,筱蒙,雪焦," \
                      "馨雨,姝瑛,湘雨,凯妍,盼溪,贵梅,巧婵,巧宁,馥瑞,业蓉,丹凤,茵程,如忆,海娟,珏朋,丽达,胜菊,岱雯,紫聪,菲凡,昭容,姝涵,昱苹,一惠,豆叮,彩云,若岚,丹琦,琳青,思,莺桦,芬," \
                      "漫呢,云娜,楚君,炳娟,英雪,妤熙,俪潆,雪彤,婧焱,韵非,雅利,芷瑜,利芳,菲晴,星语,昕颖,新熳,煜玲,岩婷,黎荭,湉心,珍珠,美萍,彦秀,钰涓,满红,良妍,颖菲,雅漩,研婷,偌遥," \
                      "贤芝,霓,斯雯,雪恬,淑芹,一萌,佳恬,俪婷,顺琼,漫旎,潇雅,猗,优优,黍娴,细霞,琇淼,翠花,黛一,淑贵,美华,于咏,爱枝,伶郦,紫佳,紫慧,茗,艺楚,艺扉,琳慧,含玥,晓薇,思燕," \
                      "馨元,晴雯,季秋,莉娜,湘君,智仙,若丝,巾谰,疏桐,春梅,钥,兰峰,雪琦,菲蕾,欣静,美红,姬,占翠,知琳,筱筱,翊岚,红岩,竞予,小花,漫,力鳗,蒙雪,云慧,英菲,瑗,占艳,红雨," \
                      "思语,思瑜,剑芳,云闲,艳花,文婕,欢欢,熠菲,夕娴,浚莉,钰萤,姚伶,叶瑶,婉琳,容韪,紫菡,黛源,筵芮,璎萌,函翊,妞,静蓉,亚男,楚苹,满雪,怀蓉,逸萌,煜葶,风瑜,黛怡,珍珍," \
                      "彩峡,安婷,苡柔,晶馨,琀骊,榆婷,静琨,蓝月,盈淼,真,淑雨,雨欣,俪予,紫琀,亚朋,小瑗,紫瑞,玉蓉,茗萱,帆菲,素琴,蒂,瑞芝,春晴,旭莺,语彤,瑾,嘉潼,哩哩,娉婷,贤雅,颖颖," \
                      "延霞,茜婷,小叶,小萌,丽,陈嫦,丹蕊,曾熠,琦瑶,从侠,海侠,珏琪,茗栾,海妹,梦童,梓潼,子菲,馨茉,又分,秋娴,鹭,琫,翠奉,偌瑶,书芳,珈嘉,晨伊,欣怡,玉滢,朋筵,苡菲,译男," \
                      "茵瞳,小莹,春慧,欣瑶,蓦瑶,熙雯,语洋,玉慧,桂莲,黎英,曾逸,惠榕,嘉姿,填艳,秋锦,尤艳,方艳,女馨,逸芳,梓舒,国兰,雨婷,茹,益兰,梦洁,虹蕾,菲帆,笑涵,岚颖,彤梦,艺萌," \
                      "婧妤,红月,洁贞,春懿,芯,讳郡,晓淇,玫莹,芹霞,春婷,金珠,均瑶,雪竹,晓霜,泽璇,丹红,伶莉,若缺,丽慧,铭淑,慧丽,保芳,译易,佳缘,柔婷,思伽,久娣,业丽,丹艺,钰茹,沁浛," \
                      "旃婴,楠,静烟,心慈,采清,作娟,晓欢,淑宇,婧宏,婧琰,盼好,子娴,蔓宸,雯鼎,莲生,思羽,智馨,圣玲,丝媛,菁璠,晓晶,萌笑,蕊,黎男,云艳,欣语,玉露,媛媛,雪倩,莉霞,芯伶,筵晰," \
                      "煜莹,筱奕,露瑾,文蕊,蓝分,甜也,楚潼,子琀,缘朋,二媛,微晞,佳晏,诗颖,辰菲,焱嫦,藜静,舒,凤娇,琨晶,菊芹,梦欣,冬菊,絮哲,媛曳,幸红,心昕,桂云,榕蕴,佳茵,盼盼,韵斐," \
                      "诗瑜,含,芹,净妃,静静,矜钥,嘉钥,雨萌,思恬,蔓瑶,莹姝,乃慧,月晗,海韵,悦恬,彩,淑英,语麦,欣艾,雅姿,艳婷,金娣,婷婷,月恬,曾谊,洪梅,建娥,占美,冰月,丽霞,倩茹,洁霖," \
                      "闲云,黎赧,恋,漪妃,芷蕾,琬昱,媛苑,碧丹,靖琪,含音,子雯,荟乐,湉仪,佳羽,艺珺,苓翊,巧荣,晓琴,文韫,茹译,舒译,松琴,乃芸,瑾璞,樱淇,琪悦,恒美,思桠,凤荣,滢舒,秀荣," \
                      "栗梅,姗娜,亦珊,慕贞,秀乡,小凤,碧月,黍沁,潇燕,静雯,米淇,盈曦,乔楠,学蓉,纯雯,璞玥,黛月,冰淼,惠丽,雨含,玉涓,爱菊,奕雯,艺霏,嵛爱,雨晴,蕙郡,梦晗,祎恬,苛茜,珏变," \
                      "晓莉,彦涵,絮琪,华英,霓芝,双双,英迪,灵,明香,新芬,善美,乐园,琬琬,玉秋,丁莉,月菱,娅书,芳茜,黛熙,琰莹,爱云,玉芳,世慧,紫璐,黎红,妙玲,招英,笑怡,瑞玉,滢淼,画,靓," \
                      "聪敏,毓婷,倩如,蕴,晓楠,雨寒,春英,义珍,雪琳,婧媛,冰晴,梦伊,耐花,亚隽,倩雅,秋梅,诗兰,子蕊,凤芝,雯怡,菲烨,艳荣,雅丽,昕心,亚茹,霁倩,梓玥,卉郡,婧菲,辰玥,漪楠," \
                      "淑霞,馨月,海霞,丽瑾,湉馨,娟芳,孓乜,悦涵,怀瑶,栩瑶,佳琳,容欢,玉璠,宝凤,靖萱,菲菲,敏嘉,小朋,雅君,巧悦,琬敏,鹃,婧彤,榕珈,绮绮,璠,语晗,楚蓠,羽菲,奕丹,宝蓓,欣竞," \
                      "橼香,溢溶,巧洁,翘,小薇,皎月,黍涓,汉娜,洪霞,溢蓉,彩桦,玲菱,璀蝉,杰媛,圆圆,毓琪,楚萍,翠翠,筵溪,玉静,霞斌,含婴,佐洁,芮儒,辛怡,晓雯,艺竞,菁涵,清雪,宇琼,思桐," \
                      "占香,慧华,子晶,瑞梅,荑,卜露,虹苏,丹梓,文侠,格畅,妮颖,思怡,琼仙,潞涵,雨娜,艺融,之倩,蕴蓥,蒙欣,露婵,嘉怡,籽柔,恬悦,译心,宝玲,玫,静胭,思飘,颖哲,芷萌,莜苒,翊妍," \
                      "月云,雯杰,佳珂,惠芳,婉菁,玉情,智岚,修兰,娅娜,巧英,茂玲,欣蕊,茵僮,金兰,雅雅,春丽,育梅,惠玲,钰清,唯依,悦琴,玉冰,芯悦,美,若雪,天英,开艳,子婴,一瑗,梦佳,雯叙," \
                      "芯蕊,永霞,鑫蕾,馨静,真艺,娉,学艳,鑫莹,云菊,静菲,婷文,格,秋,彦妮,韶婕,惠黎,容,艺涵,应梅,欣然,冰雪,凤斐,露凝,溪媛,蕾蕾,梦桃,朦月,容轩,苡馨,有琴,静贤,芝瑗," \
                      "雾瑕,艺潞,依雯,妤炯,心彤,素敏,净,晗琪,乔荟,心爱,樱萱,芯玙,俊菊,培珍,玲英,小双,靖虹,梓函,容伊,邦薇,靖晗,墨涵,冰蝉,艺晗,素芹,钰淇,莉红,惠媛,芷莹,彩嫦,潇,芷真," \
                      "二翠,春月,艳芬,沁湘,梦涵,晓兰,蕴潇,兰谊,译君,紫云,欣玥,旭瑛,秀粉,冰柠,翎,慧梅,静轩,安妮,晓春,一萍,萸艳,恚捃,筱竟,淑平,佳昕,又芬,立娜,秀容,枘雨,庆秀,春燕," \
                      "苏瑶,筵颉,芷源,可莹,绘郡,黛宁,中艳,俏寒,亚秋,雪平,梦茹,俪曦,钰妃,慧贞,巧利,净桐,世霞,荟郡,昱霏,韵奕,忻瑶,溪蕾,艾萍,嘉歆,艳辉,乙晶,秀,语昕,琳琳,邦莉,孟妍," \
                      "一珺,孝菊,涧晴,与芊,爱萍,依笑,美婷,美娟,菁妍,丽洁,昭瑗,贤翠,雪蓉,珂茜,沁韵,晶琨,丽丰,婼宝,炜婷,月煜,薪欣,丽珊,笳卉,玉瑛,纯微,仪雨,肖红,惠芬,利娟,真花,威洁," \
                      "妮妮,琳力,蕾明,艳艳,诗语,楚凤,圆,芷姗,歆,晶欣,贤珺,伟芬,心盈,双涵,梓艺,笑昀,芳敏,晓倩,桂宁,国梅,译匀,欣悦,韵寒,铁萍,邝邑,涵悦,采霞,书媛,晏彤,紫菲,云砾,鑫蕙," \
                      "梦亭,秋凝,一男,煦晴,化英,邦妹,寒素,莹琨,岚,紫暄,林芳,淑琴,巧玲,彦敏,胜娟,新艳,馨丹,改娣,梓莹,雅倩,丽威,丽市,云琦,峻莉,梓盈,馨宇,思寒,清莉,晓园,敬茹,玲玲," \
                      "采妮,雪菡,小慈,聪妮,蔓莹,小芳,小娟,馨方,先媛,雨诗,春姝,诗怡,婕,凤丹,伶妗,玥玥,珺骊,冰俏,水莲,文霞,利娜,师娴,梨梨,筵郗,娣,静焱,姝婷,羲颖,筵格,郦,英杰,迎雪," \
                      "丝嘉,媛琪,丽欣,灵琴,雪会,寒莹,媚莹,薇,芝榕,晓慧,斯语,雁冰,青敏,莎莎,秀慧,倩云,荣珠,惠璞,晗涵,英睿,舒馨,平芝,真瑜,丽惠,苓菱,雅琦,钰洁,黎喃,办艳,育红,海燕," \
                      "弈茹,筵曦,予婕,湄姗,一卉,仪凡,嫦茜,佳湘,紫薇,慧宇,云芳,芸菁,小珊,雅秋,俏明,紫帆,淑芬,薇文,晓涵,昭雪,溶依,丽华,芮曦,竞男,叶,淑烨,舒沁,琳茜,佳,娉娉,群媚,晓云," \
                      "津樱,桐俏,蕴茴,心兰,立萍,缠糯,瑗琪,艾娜,润妍,云霞,语童,秋香,蓓,颜,月琪,彦婕,境薇,秀瑛,凤贵,雨霏,悦含,颖佳,彤彤,飒,嘉薇,丹扬,兴茹,中花,一菲,唯伊,锦芝,佳咨," \
                      "乙潞,筱宇,潇蔷,秋花,宇萱,思晨,一萱,金瑶,紫莹,芝华,伟娟,珏文,佐婕,玉儿,津芝,璧儿,斓菲,飘,笑萱,玉翠,颖乙,敏焰,金枝,苗潇,鑫媛,朵菡,雪蕊,艳,美雯,永兰,庆玲,聪娅," \
                      "籽烨,恭兰,家珍,仪涵,常秀,文娟,玄睫,焕莉,漫妮,子萱,冬青,薇茹,了尹,敬莎,路语,潇缤,晗彤,竞丹,婧文,甜语,曾翊,嘉琳,昭茜,若兰,祺玥,婧,汝雯,彦瑾,丽鑫,婷玉,以柔," \
                      "旭缨,佳姊,语燕,秀美,紫寒,泺滢,莛,小丽,丽菲,若涵,馨田,奕洁,雅雯,秀云,云舒,筠,娈,婉杉,沁涵,琳佳,沁雅,思晗,莺宁,旭晶,尹倩,庭凤,菁琰,芷蔓,彦芹,秋月,晓漫,馨仪," \
                      "韶韵,苏钰,忆琛,盼曦,嫣,业莹,晓侠,子莉,姬月,佳梓,曼婷,焕婷,靓妍,远萍,依霖,薇茜,丽珠,黛毓,晨思,国艳,君玉,芮,菁菡,骊骊,兮艳,书沁,邰璇,如艺,怡甜,丹璐,乙彤,晗悦," \
                      "漫雪,尘香,芷涵,讳筠,宁忆,蕴萦,雪,英华,东丽,景芳,寒怡,琳,思楠,湘佳,菲雪,韵舒,誉玲,冰露,芸萌,雨舒,婧帆,水馨,雪娇,思予,雅芙,淑华,浚俐,增彩,栖蕴,玺凤,藤容,元芳," \
                      "景月,双男,笑雯,珏灵,雨烟,小琴,索霏,湘语,誉艳,箐,雯跃,润芳,爱芝,珏婷,芮萱,楚涵,雪拽,紫璇,奕妍,煜婷,可悦,彦莲,朵朵,苏苏,琴燕,智燕,娟花,贝贝,敬玲,鹤丹,丹奇," \
                      "馨卉,思仪,学玲,靖芝,诗涵,苡葶,英芳,妍姿,馨伊,琰婷,雨雯,昭媛,雁茹,华妮,舒文,萍玲,羽亭,溪铃,俊霞,月心,莹,兰子,嘉薪,建仙,阅涵,钰芳,昕怡,蔓宇,芷槿,海聆,子婵,旎," \
                      "亚玲,秋六,萌烨,文娇,瑞兰,克娥,乙涵,丹冰,海丽,梓含,义芳,片艳,菁蕊,春霞,玲娟,菁嫣,栖含,佁函,笛笛,思暮,桂香,季月,乙露,惠惠,雯琳,椿燕,凤仙,思侠,爱桐,湘梦,煜莺," \
                      "敬怡,文静,绣玲,爱媛,歆洁,玉淇,筱彦,雅苹,苏诺,煊婷,邦倩,怡芮,佳芮,宝琴,斐然,绮晗,媛,旭瑶,乙伊,谦影,楠楠,荔莉,语瞳,小语,之侠,书莲,姿萱,妤伊,金花,莲珍,羽潼," \
                      "予绮,若晴,莲泯,紫沐,诗琴,崴茹,伊涵,心怡,乐怡,菀莹,佛兰,僖玉,蕴涵,语桐,曾宜,瑞巧,惠丹,慧,艺琼,清红,昱惠,芮菡,克娟,溪潺,书瑶,沁凡,舒晨,星慧,倩菲,美玲,姣姣," \
                      "艾珂,彦静,玉芝,惠,亚君,翠华,凯媛,芮希,笑卿,紫玥,宁茜,蒴,婕媛,婧宁,嗉凤,守芬,雪昕,秀琴,红云,翊函,星燕,月淼,紫耘,佼,晓娟,琬童,英舜,鹤馨,钰滢,琬,佳沐,燕妮," \
                      "晓珊,秀杰,惠琳,英春,馨忆,婕杏,贤凤,妍卿,素云,筠鸿,春茜,庆霞,馥琳,一莉,红果,喏璐,泓曾,运珍,伶丽,海含,碧悦,婕羽,羽洁,浛,秀芹,佳心,凤艳,静姝,爱卿,诗韵,巧云," \
                      "悦婷,佳旋,田娅,颖鑫,幸溶,欢,世琴,燕玲,邦梅,如兰,苡荣,凤麟,灿蓓,骊,弦月,雪凡,亚琛,晓佳,雯一,弈莹,竹连,静虹,葑,睿馥,敏,秋虹,莎,晓红,艳波,梦珍,寒冰,秀娥,斯妍," \
                      "绮鑫,军花,珊,冬莲,窈嫒,世美,银珠,欣湉,彭媛,欣霏,菁焰,玲鑫,如诗,绍莲,菲梵,若音,江丽,文秀,美琳,茜宝,佳孜,利英,左洁,艳平,文婷,玉鹃,琪琪,影萍,艺雯,月蘅,寒笛," \
                      "冰禅,雯华,静岩,建英,小瑶,淑慧,栉烨,佳姿,颖巍,彦萌,淑征,偌晗,语湘,什艳,宏丽,斯羽,禹菡,琨静,璇海,于娴,韵沁,晓琪,萌昀,黍婵,金荟,志茹,晶婧,秀彦,允琳,容容,黎虹," \
                      "琪蔚,筱淇,慧扬,建秀,玲丽,琳颉,思悦,琨莹,巍娟,碧桃,菡悦,鑫洁,露露,文菊,彤屿,锦月,纨,桂芝,舒帆,慧蓉,素萍,秀茹,恬妞,新月,才茹,一霏,书琴,婧懿,茹春,玥心,淑存," \
                      "雅慈,一靓,璇,雯淇,桠菽,赛琦,琰萍,光雯,小慧,大珍,婧暄,月晶,含颖,妍熹,旭慧,梓喃,秋莲,潇莹,荟冰,筠莉,昆丽,丽婷,雅湘,锦芳,俊英,小筱,内艳,雯露,心菁,紫涵,茜如," \
                      "誉娟,娴,馨如,籽昱,若晗,云媛,瑶蓓,聪雅,歆童,又砾,碧君,亚春,童漩,纤男,雯岚,源梦,萌乐,俊菲,小霞,炎婷,晰晴,新英,梓茵,海蓉,语娜,馨琦,晓馥,佳翊 "
        self.names = nameStr.split(",")
        self.bodyNames = bodyNameStr.split(",")
        self.girlNames = girlNameStr.split(",")

    def getBodyName(self):
        """
        随机获取一个男孩姓名
        :return:
        """
        fullName = f"{randomItem(self.names)}{randomItem(self.bodyNames)}"
        return fullName

    def getGirlName(self):
        """
        随机获取一个女孩姓名
        :return:
        """
        fullName = f"{randomItem(self.names)}{randomItem(self.girlNames)}"
        return fullName

    def getName(self):
        """
        随机获取一个姓名
        :return:
        """
        return randomBool() and self.getBodyName() or self.getGirlName()


__name_creator = NameCreator()


def randomBodyName():
    """
    随机获取一个男孩姓名
    :return:
    """
    return __name_creator.getBodyName()


def randomGirlName():
    """
    随机获取一个女孩姓名
    :return:
    """
    return __name_creator.getGirlName()


def randomName():
    """
    随机获取一个姓名
    :return:
    """
    return __name_creator.getName()

# 2021年12月中华人民共和国县以上行政区划代码
# 爬取：http://www.stats.gov.cn/tjsj/tjbz/tjyqhdmhcxhfdm/2021/index.html
# 行政区划代码:单位名称

class AreaCreator(object):
    def __init__(self):
        self.__data_map = {
            "110000": "北京市",
            "110101": "东城区",
            "110102": "西城区",
            "110105": "朝阳区",
            "110106": "丰台区",
            "110107": "石景山区",
            "110108": "海淀区",
            "110109": "门头沟区",
            "110111": "房山区",
            "110112": "通州区",
            "110113": "顺义区",
            "110114": "昌平区",
            "110115": "大兴区",
            "110116": "怀柔区",
            "110117": "平谷区",
            "110118": "密云区",
            "110119": "延庆区",
            "120000": "天津市",
            "120101": "和平区",
            "120102": "河东区",
            "120103": "河西区",
            "120104": "南开区",
            "120105": "河北区",
            "120106": "红桥区",
            "120110": "东丽区",
            "120111": "西青区",
            "120112": "津南区",
            "120113": "北辰区",
            "120114": "武清区",
            "120115": "宝坻区",
            "120116": "滨海新区",
            "120117": "宁河区",
            "120118": "静海区",
            "120119": "蓟州区",
            "130100": "石家庄市",
            "130000": "河北省",
            "130102": "长安区",
            "130104": "桥西区",
            "130105": "新华区",
            "130107": "井陉矿区",
            "130108": "裕华区",
            "130109": "藁城区",
            "130110": "鹿泉区",
            "130111": "栾城区",
            "130121": "井陉县",
            "130123": "正定县",
            "130125": "行唐县",
            "130126": "灵寿县",
            "130127": "高邑县",
            "130128": "深泽县",
            "130129": "赞皇县",
            "130130": "无极县",
            "130131": "平山县",
            "130132": "元氏县",
            "130133": "赵县",
            "130171": "石家庄高新技术产业开发区",
            "130172": "石家庄循环化工园区",
            "130181": "辛集市",
            "130183": "晋州市",
            "130184": "新乐市",
            "130200": "唐山市",
            "130202": "路南区",
            "130203": "路北区",
            "130204": "古冶区",
            "130205": "开平区",
            "130207": "丰南区",
            "130208": "丰润区",
            "130209": "曹妃甸区",
            "130224": "滦南县",
            "130225": "乐亭县",
            "130227": "迁西县",
            "130229": "玉田县",
            "130271": "河北唐山芦台经济开发区",
            "130272": "唐山市汉沽管理区",
            "130273": "唐山高新技术产业开发区",
            "130274": "河北唐山海港经济开发区",
            "130281": "遵化市",
            "130283": "迁安市",
            "130284": "滦州市",
            "130300": "秦皇岛市",
            "130302": "海港区",
            "130303": "山海关区",
            "130304": "北戴河区",
            "130306": "抚宁区",
            "130321": "青龙满族自治县",
            "130322": "昌黎县",
            "130324": "卢龙县",
            "130371": "秦皇岛市经济技术开发区",
            "130372": "北戴河新区",
            "130400": "邯郸市",
            "130402": "邯山区",
            "130403": "丛台区",
            "130404": "复兴区",
            "130406": "峰峰矿区",
            "130407": "肥乡区",
            "130408": "永年区",
            "130423": "临漳县",
            "130424": "成安县",
            "130425": "大名县",
            "130426": "涉县",
            "130427": "磁县",
            "130430": "邱县",
            "130431": "鸡泽县",
            "130432": "广平县",
            "130433": "馆陶县",
            "130434": "魏县",
            "130435": "曲周县",
            "130471": "邯郸经济技术开发区",
            "130473": "邯郸冀南新区",
            "130481": "武安市",
            "130500": "邢台市",
            "130502": "襄都区",
            "130503": "信都区",
            "130505": "任泽区",
            "130506": "南和区",
            "130522": "临城县",
            "130523": "内丘县",
            "130524": "柏乡县",
            "130525": "隆尧县",
            "130528": "宁晋县",
            "130529": "巨鹿县",
            "130530": "新河县",
            "130531": "广宗县",
            "130532": "平乡县",
            "130533": "威县",
            "130534": "清河县",
            "130535": "临西县",
            "130571": "河北邢台经济开发区",
            "130581": "南宫市",
            "130582": "沙河市",
            "130600": "保定市",
            "130602": "竞秀区",
            "130606": "莲池区",
            "130607": "满城区",
            "130608": "清苑区",
            "130609": "徐水区",
            "130623": "涞水县",
            "130624": "阜平县",
            "130626": "定兴县",
            "130627": "唐县",
            "130628": "高阳县",
            "130629": "容城县",
            "130630": "涞源县",
            "130631": "望都县",
            "130632": "安新县",
            "130633": "易县",
            "130634": "曲阳县",
            "130635": "蠡县",
            "130636": "顺平县",
            "130637": "博野县",
            "130638": "雄县",
            "130671": "保定高新技术产业开发区",
            "130672": "保定白沟新城",
            "130681": "涿州市",
            "130682": "定州市",
            "130683": "安国市",
            "130684": "高碑店市",
            "130700": "张家口市",
            "130702": "桥东区",
            "130703": "桥西区",
            "130705": "宣化区",
            "130706": "下花园区",
            "130708": "万全区",
            "130709": "崇礼区",
            "130722": "张北县",
            "130723": "康保县",
            "130724": "沽源县",
            "130725": "尚义县",
            "130726": "蔚县",
            "130727": "阳原县",
            "130728": "怀安县",
            "130730": "怀来县",
            "130731": "涿鹿县",
            "130732": "赤城县",
            "130771": "张家口经济开发区",
            "130772": "张家口市察北管理区",
            "130773": "张家口市塞北管理区",
            "130800": "承德市",
            "130802": "双桥区",
            "130803": "双滦区",
            "130804": "鹰手营子矿区",
            "130821": "承德县",
            "130822": "兴隆县",
            "130824": "滦平县",
            "130825": "隆化县",
            "130826": "丰宁满族自治县",
            "130827": "宽城满族自治县",
            "130828": "围场满族蒙古族自治县",
            "130871": "承德高新技术产业开发区",
            "130881": "平泉市",
            "130900": "沧州市",
            "130902": "新华区",
            "130903": "运河区",
            "130921": "沧县",
            "130922": "青县",
            "130923": "东光县",
            "130924": "海兴县",
            "130925": "盐山县",
            "130926": "肃宁县",
            "130927": "南皮县",
            "130928": "吴桥县",
            "130929": "献县",
            "130930": "孟村回族自治县",
            "130971": "河北沧州经济开发区",
            "130972": "沧州高新技术产业开发区",
            "130973": "沧州渤海新区",
            "130981": "泊头市",
            "130982": "任丘市",
            "130983": "黄骅市",
            "130984": "河间市",
            "131000": "廊坊市",
            "131002": "安次区",
            "131003": "广阳区",
            "131022": "固安县",
            "131023": "永清县",
            "131024": "香河县",
            "131025": "大城县",
            "131026": "文安县",
            "131028": "大厂回族自治县",
            "131071": "廊坊经济技术开发区",
            "131081": "霸州市",
            "131082": "三河市",
            "131100": "衡水市",
            "131102": "桃城区",
            "131103": "冀州区",
            "131121": "枣强县",
            "131122": "武邑县",
            "131123": "武强县",
            "131124": "饶阳县",
            "131125": "安平县",
            "131126": "故城县",
            "131127": "景县",
            "131128": "阜城县",
            "131171": "河北衡水高新技术产业开发区",
            "131172": "衡水滨湖新区",
            "131182": "深州市",
            "140100": "太原市",
            "140000": "山西省",
            "140105": "小店区",
            "140106": "迎泽区",
            "140107": "杏花岭区",
            "140108": "尖草坪区",
            "140109": "万柏林区",
            "140110": "晋源区",
            "140121": "清徐县",
            "140122": "阳曲县",
            "140123": "娄烦县",
            "140171": "山西转型综合改革示范区",
            "140181": "古交市",
            "140200": "大同市",
            "140212": "新荣区",
            "140213": "平城区",
            "140214": "云冈区",
            "140215": "云州区",
            "140221": "阳高县",
            "140222": "天镇县",
            "140223": "广灵县",
            "140224": "灵丘县",
            "140225": "浑源县",
            "140226": "左云县",
            "140271": "山西大同经济开发区",
            "140300": "阳泉市",
            "140302": "城区",
            "140303": "矿区",
            "140311": "郊区",
            "140321": "平定县",
            "140322": "盂县",
            "140400": "长治市",
            "140403": "潞州区",
            "140404": "上党区",
            "140405": "屯留区",
            "140406": "潞城区",
            "140423": "襄垣县",
            "140425": "平顺县",
            "140426": "黎城县",
            "140427": "壶关县",
            "140428": "长子县",
            "140429": "武乡县",
            "140430": "沁县",
            "140431": "沁源县",
            "140471": "山西长治高新技术产业园区",
            "140500": "晋城市",
            "140502": "城区",
            "140521": "沁水县",
            "140522": "阳城县",
            "140524": "陵川县",
            "140525": "泽州县",
            "140581": "高平市",
            "140600": "朔州市",
            "140602": "朔城区",
            "140603": "平鲁区",
            "140621": "山阴县",
            "140622": "应县",
            "140623": "右玉县",
            "140671": "山西朔州经济开发区",
            "140681": "怀仁市",
            "140700": "晋中市",
            "140702": "榆次区",
            "140703": "太谷区",
            "140721": "榆社县",
            "140722": "左权县",
            "140723": "和顺县",
            "140724": "昔阳县",
            "140725": "寿阳县",
            "140727": "祁县",
            "140728": "平遥县",
            "140729": "灵石县",
            "140781": "介休市",
            "140800": "运城市",
            "140802": "盐湖区",
            "140821": "临猗县",
            "140822": "万荣县",
            "140823": "闻喜县",
            "140824": "稷山县",
            "140825": "新绛县",
            "140826": "绛县",
            "140827": "垣曲县",
            "140828": "夏县",
            "140829": "平陆县",
            "140830": "芮城县",
            "140881": "永济市",
            "140882": "河津市",
            "140900": "忻州市",
            "140902": "忻府区",
            "140921": "定襄县",
            "140922": "五台县",
            "140923": "代县",
            "140924": "繁峙县",
            "140925": "宁武县",
            "140926": "静乐县",
            "140927": "神池县",
            "140928": "五寨县",
            "140929": "岢岚县",
            "140930": "河曲县",
            "140931": "保德县",
            "140932": "偏关县",
            "140971": "五台山风景名胜区",
            "140981": "原平市",
            "141000": "临汾市",
            "141002": "尧都区",
            "141021": "曲沃县",
            "141022": "翼城县",
            "141023": "襄汾县",
            "141024": "洪洞县",
            "141025": "古县",
            "141026": "安泽县",
            "141027": "浮山县",
            "141028": "吉县",
            "141029": "乡宁县",
            "141030": "大宁县",
            "141031": "隰县",
            "141032": "永和县",
            "141033": "蒲县",
            "141034": "汾西县",
            "141081": "侯马市",
            "141082": "霍州市",
            "141100": "吕梁市",
            "141102": "离石区",
            "141121": "文水县",
            "141122": "交城县",
            "141123": "兴县",
            "141124": "临县",
            "141125": "柳林县",
            "141126": "石楼县",
            "141127": "岚县",
            "141128": "方山县",
            "141129": "中阳县",
            "141130": "交口县",
            "141181": "孝义市",
            "141182": "汾阳市",
            "150100": "呼和浩特市",
            "150000": "内蒙古自治区",
            "150102": "新城区",
            "150103": "回民区",
            "150104": "玉泉区",
            "150105": "赛罕区",
            "150121": "土默特左旗",
            "150122": "托克托县",
            "150123": "和林格尔县",
            "150124": "清水河县",
            "150125": "武川县",
            "150172": "呼和浩特经济技术开发区",
            "150200": "包头市",
            "150202": "东河区",
            "150203": "昆都仑区",
            "150204": "青山区",
            "150205": "石拐区",
            "150206": "白云鄂博矿区",
            "150207": "九原区",
            "150221": "土默特右旗",
            "150222": "固阳县",
            "150223": "达尔罕茂明安联合旗",
            "150271": "包头稀土高新技术产业开发区",
            "150300": "乌海市",
            "150302": "海勃湾区",
            "150303": "海南区",
            "150304": "乌达区",
            "150400": "赤峰市",
            "150402": "红山区",
            "150403": "元宝山区",
            "150404": "松山区",
            "150421": "阿鲁科尔沁旗",
            "150422": "巴林左旗",
            "150423": "巴林右旗",
            "150424": "林西县",
            "150425": "克什克腾旗",
            "150426": "翁牛特旗",
            "150428": "喀喇沁旗",
            "150429": "宁城县",
            "150430": "敖汉旗",
            "150500": "通辽市",
            "150502": "科尔沁区",
            "150521": "科尔沁左翼中旗",
            "150522": "科尔沁左翼后旗",
            "150523": "开鲁县",
            "150524": "库伦旗",
            "150525": "奈曼旗",
            "150526": "扎鲁特旗",
            "150571": "通辽经济技术开发区",
            "150581": "霍林郭勒市",
            "150600": "鄂尔多斯市",
            "150602": "东胜区",
            "150603": "康巴什区",
            "150621": "达拉特旗",
            "150622": "准格尔旗",
            "150623": "鄂托克前旗",
            "150624": "鄂托克旗",
            "150625": "杭锦旗",
            "150626": "乌审旗",
            "150627": "伊金霍洛旗",
            "150700": "呼伦贝尔市",
            "150702": "海拉尔区",
            "150703": "扎赉诺尔区",
            "150721": "阿荣旗",
            "150722": "莫力达瓦达斡尔族自治旗",
            "150723": "鄂伦春自治旗",
            "150724": "鄂温克族自治旗",
            "150725": "陈巴尔虎旗",
            "150726": "新巴尔虎左旗",
            "150727": "新巴尔虎右旗",
            "150781": "满洲里市",
            "150782": "牙克石市",
            "150783": "扎兰屯市",
            "150784": "额尔古纳市",
            "150785": "根河市",
            "150800": "巴彦淖尔市",
            "150802": "临河区",
            "150821": "五原县",
            "150822": "磴口县",
            "150823": "乌拉特前旗",
            "150824": "乌拉特中旗",
            "150825": "乌拉特后旗",
            "150826": "杭锦后旗",
            "150900": "乌兰察布市",
            "150902": "集宁区",
            "150921": "卓资县",
            "150922": "化德县",
            "150923": "商都县",
            "150924": "兴和县",
            "150925": "凉城县",
            "150926": "察哈尔右翼前旗",
            "150927": "察哈尔右翼中旗",
            "150928": "察哈尔右翼后旗",
            "150929": "四子王旗",
            "150981": "丰镇市",
            "152200": "兴安盟",
            "152201": "乌兰浩特市",
            "152202": "阿尔山市",
            "152221": "科尔沁右翼前旗",
            "152222": "科尔沁右翼中旗",
            "152223": "扎赉特旗",
            "152224": "突泉县",
            "152500": "锡林郭勒盟",
            "152501": "二连浩特市",
            "152502": "锡林浩特市",
            "152522": "阿巴嘎旗",
            "152523": "苏尼特左旗",
            "152524": "苏尼特右旗",
            "152525": "东乌珠穆沁旗",
            "152526": "西乌珠穆沁旗",
            "152527": "太仆寺旗",
            "152528": "镶黄旗",
            "152529": "正镶白旗",
            "152530": "正蓝旗",
            "152531": "多伦县",
            "152571": "乌拉盖管委会",
            "152900": "阿拉善盟",
            "152921": "阿拉善左旗",
            "152922": "阿拉善右旗",
            "152923": "额济纳旗",
            "152971": "内蒙古阿拉善高新技术产业开发区",
            "210100": "沈阳市",
            "210000": "辽宁省",
            "210102": "和平区",
            "210103": "沈河区",
            "210104": "大东区",
            "210105": "皇姑区",
            "210106": "铁西区",
            "210111": "苏家屯区",
            "210112": "浑南区",
            "210113": "沈北新区",
            "210114": "于洪区",
            "210115": "辽中区",
            "210123": "康平县",
            "210124": "法库县",
            "210181": "新民市",
            "210200": "大连市",
            "210202": "中山区",
            "210203": "西岗区",
            "210204": "沙河口区",
            "210211": "甘井子区",
            "210212": "旅顺口区",
            "210213": "金州区",
            "210214": "普兰店区",
            "210224": "长海县",
            "210281": "瓦房店市",
            "210283": "庄河市",
            "210300": "鞍山市",
            "210302": "铁东区",
            "210303": "铁西区",
            "210304": "立山区",
            "210311": "千山区",
            "210321": "台安县",
            "210323": "岫岩满族自治县",
            "210381": "海城市",
            "210400": "抚顺市",
            "210402": "新抚区",
            "210403": "东洲区",
            "210404": "望花区",
            "210411": "顺城区",
            "210421": "抚顺县",
            "210422": "新宾满族自治县",
            "210423": "清原满族自治县",
            "210500": "本溪市",
            "210502": "平山区",
            "210503": "溪湖区",
            "210504": "明山区",
            "210505": "南芬区",
            "210521": "本溪满族自治县",
            "210522": "桓仁满族自治县",
            "210600": "丹东市",
            "210602": "元宝区",
            "210603": "振兴区",
            "210604": "振安区",
            "210624": "宽甸满族自治县",
            "210681": "东港市",
            "210682": "凤城市",
            "210700": "锦州市",
            "210702": "古塔区",
            "210703": "凌河区",
            "210711": "太和区",
            "210726": "黑山县",
            "210727": "义县",
            "210781": "凌海市",
            "210782": "北镇市",
            "210800": "营口市",
            "210802": "站前区",
            "210803": "西市区",
            "210804": "鲅鱼圈区",
            "210811": "老边区",
            "210881": "盖州市",
            "210882": "大石桥市",
            "210900": "阜新市",
            "210902": "海州区",
            "210903": "新邱区",
            "210904": "太平区",
            "210905": "清河门区",
            "210911": "细河区",
            "210921": "阜新蒙古族自治县",
            "210922": "彰武县",
            "211000": "辽阳市",
            "211002": "白塔区",
            "211003": "文圣区",
            "211004": "宏伟区",
            "211005": "弓长岭区",
            "211011": "太子河区",
            "211021": "辽阳县",
            "211081": "灯塔市",
            "211100": "盘锦市",
            "211102": "双台子区",
            "211103": "兴隆台区",
            "211104": "大洼区",
            "211122": "盘山县",
            "211200": "铁岭市",
            "211202": "银州区",
            "211204": "清河区",
            "211221": "铁岭县",
            "211223": "西丰县",
            "211224": "昌图县",
            "211281": "调兵山市",
            "211282": "开原市",
            "211300": "朝阳市",
            "211302": "双塔区",
            "211303": "龙城区",
            "211321": "朝阳县",
            "211322": "建平县",
            "211324": "喀喇沁左翼蒙古族自治县",
            "211381": "北票市",
            "211382": "凌源市",
            "211400": "葫芦岛市",
            "211402": "连山区",
            "211403": "龙港区",
            "211404": "南票区",
            "211421": "绥中县",
            "211422": "建昌县",
            "211481": "兴城市",
            "220100": "长春市",
            "220000": "吉林省",
            "220102": "南关区",
            "220103": "宽城区",
            "220104": "朝阳区",
            "220105": "二道区",
            "220106": "绿园区",
            "220112": "双阳区",
            "220113": "九台区",
            "220122": "农安县",
            "220171": "长春经济技术开发区",
            "220172": "长春净月高新技术产业开发区",
            "220173": "长春高新技术产业开发区",
            "220174": "长春汽车经济技术开发区",
            "220182": "榆树市",
            "220183": "德惠市",
            "220184": "公主岭市",
            "220200": "吉林市",
            "220202": "昌邑区",
            "220203": "龙潭区",
            "220204": "船营区",
            "220211": "丰满区",
            "220221": "永吉县",
            "220271": "吉林经济开发区",
            "220272": "吉林高新技术产业开发区",
            "220273": "吉林中国新加坡食品区",
            "220281": "蛟河市",
            "220282": "桦甸市",
            "220283": "舒兰市",
            "220284": "磐石市",
            "220300": "四平市",
            "220302": "铁西区",
            "220303": "铁东区",
            "220322": "梨树县",
            "220323": "伊通满族自治县",
            "220382": "双辽市",
            "220400": "辽源市",
            "220402": "龙山区",
            "220403": "西安区",
            "220421": "东丰县",
            "220422": "东辽县",
            "220500": "通化市",
            "220502": "东昌区",
            "220503": "二道江区",
            "220521": "通化县",
            "220523": "辉南县",
            "220524": "柳河县",
            "220581": "梅河口市",
            "220582": "集安市",
            "220600": "白山市",
            "220602": "浑江区",
            "220605": "江源区",
            "220621": "抚松县",
            "220622": "靖宇县",
            "220623": "长白朝鲜族自治县",
            "220681": "临江市",
            "220700": "松原市",
            "220702": "宁江区",
            "220721": "前郭尔罗斯蒙古族自治县",
            "220722": "长岭县",
            "220723": "乾安县",
            "220771": "吉林松原经济开发区",
            "220781": "扶余市",
            "220800": "白城市",
            "220802": "洮北区",
            "220821": "镇赉县",
            "220822": "通榆县",
            "220871": "吉林白城经济开发区",
            "220881": "洮南市",
            "220882": "大安市",
            "222400": "延边朝鲜族自治州",
            "222401": "延吉市",
            "222402": "图们市",
            "222403": "敦化市",
            "222404": "珲春市",
            "222405": "龙井市",
            "222406": "和龙市",
            "222424": "汪清县",
            "222426": "安图县",
            "230100": "哈尔滨市",
            "230000": "黑龙江省",
            "230102": "道里区",
            "230103": "南岗区",
            "230104": "道外区",
            "230108": "平房区",
            "230109": "松北区",
            "230110": "香坊区",
            "230111": "呼兰区",
            "230112": "阿城区",
            "230113": "双城区",
            "230123": "依兰县",
            "230124": "方正县",
            "230125": "宾县",
            "230126": "巴彦县",
            "230127": "木兰县",
            "230128": "通河县",
            "230129": "延寿县",
            "230183": "尚志市",
            "230184": "五常市",
            "230200": "齐齐哈尔市",
            "230202": "龙沙区",
            "230203": "建华区",
            "230204": "铁锋区",
            "230205": "昂昂溪区",
            "230206": "富拉尔基区",
            "230207": "碾子山区",
            "230208": "梅里斯达斡尔族区",
            "230221": "龙江县",
            "230223": "依安县",
            "230224": "泰来县",
            "230225": "甘南县",
            "230227": "富裕县",
            "230229": "克山县",
            "230230": "克东县",
            "230231": "拜泉县",
            "230281": "讷河市",
            "230300": "鸡西市",
            "230302": "鸡冠区",
            "230303": "恒山区",
            "230304": "滴道区",
            "230305": "梨树区",
            "230306": "城子河区",
            "230307": "麻山区",
            "230321": "鸡东县",
            "230381": "虎林市",
            "230382": "密山市",
            "230400": "鹤岗市",
            "230402": "向阳区",
            "230403": "工农区",
            "230404": "南山区",
            "230405": "兴安区",
            "230406": "东山区",
            "230407": "兴山区",
            "230421": "萝北县",
            "230422": "绥滨县",
            "230500": "双鸭山市",
            "230502": "尖山区",
            "230503": "岭东区",
            "230505": "四方台区",
            "230506": "宝山区",
            "230521": "集贤县",
            "230522": "友谊县",
            "230523": "宝清县",
            "230524": "饶河县",
            "230600": "大庆市",
            "230602": "萨尔图区",
            "230603": "龙凤区",
            "230604": "让胡路区",
            "230605": "红岗区",
            "230606": "大同区",
            "230621": "肇州县",
            "230622": "肇源县",
            "230623": "林甸县",
            "230624": "杜尔伯特蒙古族自治县",
            "230671": "大庆高新技术产业开发区",
            "230700": "伊春市",
            "230717": "伊美区",
            "230718": "乌翠区",
            "230719": "友好区",
            "230722": "嘉荫县",
            "230723": "汤旺县",
            "230724": "丰林县",
            "230725": "大箐山县",
            "230726": "南岔县",
            "230751": "金林区",
            "230781": "铁力市",
            "230800": "佳木斯市",
            "230803": "向阳区",
            "230804": "前进区",
            "230805": "东风区",
            "230811": "郊区",
            "230822": "桦南县",
            "230826": "桦川县",
            "230828": "汤原县",
            "230881": "同江市",
            "230882": "富锦市",
            "230883": "抚远市",
            "230900": "七台河市",
            "230902": "新兴区",
            "230903": "桃山区",
            "230904": "茄子河区",
            "230921": "勃利县",
            "231000": "牡丹江市",
            "231002": "东安区",
            "231003": "阳明区",
            "231004": "爱民区",
            "231005": "西安区",
            "231025": "林口县",
            "231071": "牡丹江经济技术开发区",
            "231081": "绥芬河市",
            "231083": "海林市",
            "231084": "宁安市",
            "231085": "穆棱市",
            "231086": "东宁市",
            "231100": "黑河市",
            "231102": "爱辉区",
            "231123": "逊克县",
            "231124": "孙吴县",
            "231181": "北安市",
            "231182": "五大连池市",
            "231183": "嫩江市",
            "231200": "绥化市",
            "231202": "北林区",
            "231221": "望奎县",
            "231222": "兰西县",
            "231223": "青冈县",
            "231224": "庆安县",
            "231225": "明水县",
            "231226": "绥棱县",
            "231281": "安达市",
            "231282": "肇东市",
            "231283": "海伦市",
            "232700": "大兴安岭地区",
            "232701": "漠河市",
            "232721": "呼玛县",
            "232722": "塔河县",
            "232761": "加格达奇区",
            "232762": "松岭区",
            "232763": "新林区",
            "232764": "呼中区",
            "310000": "上海市",
            "310101": "黄浦区",
            "310104": "徐汇区",
            "310105": "长宁区",
            "310106": "静安区",
            "310107": "普陀区",
            "310109": "虹口区",
            "310110": "杨浦区",
            "310112": "闵行区",
            "310113": "宝山区",
            "310114": "嘉定区",
            "310115": "浦东新区",
            "310116": "金山区",
            "310117": "松江区",
            "310118": "青浦区",
            "310120": "奉贤区",
            "310151": "崇明区",
            "320100": "南京市",
            "320000": "江苏省",
            "320102": "玄武区",
            "320104": "秦淮区",
            "320105": "建邺区",
            "320106": "鼓楼区",
            "320111": "浦口区",
            "320113": "栖霞区",
            "320114": "雨花台区",
            "320115": "江宁区",
            "320116": "六合区",
            "320117": "溧水区",
            "320118": "高淳区",
            "320200": "无锡市",
            "320205": "锡山区",
            "320206": "惠山区",
            "320211": "滨湖区",
            "320213": "梁溪区",
            "320214": "新吴区",
            "320281": "江阴市",
            "320282": "宜兴市",
            "320300": "徐州市",
            "320302": "鼓楼区",
            "320303": "云龙区",
            "320305": "贾汪区",
            "320311": "泉山区",
            "320312": "铜山区",
            "320321": "丰县",
            "320322": "沛县",
            "320324": "睢宁县",
            "320371": "徐州经济技术开发区",
            "320381": "新沂市",
            "320382": "邳州市",
            "320400": "常州市",
            "320402": "天宁区",
            "320404": "钟楼区",
            "320411": "新北区",
            "320412": "武进区",
            "320413": "金坛区",
            "320481": "溧阳市",
            "320500": "苏州市",
            "320505": "虎丘区",
            "320506": "吴中区",
            "320507": "相城区",
            "320508": "姑苏区",
            "320509": "吴江区",
            "320571": "苏州工业园区",
            "320581": "常熟市",
            "320582": "张家港市",
            "320583": "昆山市",
            "320585": "太仓市",
            "320600": "南通市",
            "320612": "通州区",
            "320613": "崇川区",
            "320614": "海门区",
            "320623": "如东县",
            "320671": "南通经济技术开发区",
            "320681": "启东市",
            "320682": "如皋市",
            "320685": "海安市",
            "320700": "连云港市",
            "320703": "连云区",
            "320706": "海州区",
            "320707": "赣榆区",
            "320722": "东海县",
            "320723": "灌云县",
            "320724": "灌南县",
            "320771": "连云港经济技术开发区",
            "320772": "连云港高新技术产业开发区",
            "320800": "淮安市",
            "320803": "淮安区",
            "320804": "淮阴区",
            "320812": "清江浦区",
            "320813": "洪泽区",
            "320826": "涟水县",
            "320830": "盱眙县",
            "320831": "金湖县",
            "320871": "淮安经济技术开发区",
            "320900": "盐城市",
            "320902": "亭湖区",
            "320903": "盐都区",
            "320904": "大丰区",
            "320921": "响水县",
            "320922": "滨海县",
            "320923": "阜宁县",
            "320924": "射阳县",
            "320925": "建湖县",
            "320971": "盐城经济技术开发区",
            "320981": "东台市",
            "321000": "扬州市",
            "321002": "广陵区",
            "321003": "邗江区",
            "321012": "江都区",
            "321023": "宝应县",
            "321071": "扬州经济技术开发区",
            "321081": "仪征市",
            "321084": "高邮市",
            "321100": "镇江市",
            "321102": "京口区",
            "321111": "润州区",
            "321112": "丹徒区",
            "321171": "镇江新区",
            "321181": "丹阳市",
            "321182": "扬中市",
            "321183": "句容市",
            "321200": "泰州市",
            "321202": "海陵区",
            "321203": "高港区",
            "321204": "姜堰区",
            "321271": "泰州医药高新技术产业开发区",
            "321281": "兴化市",
            "321282": "靖江市",
            "321283": "泰兴市",
            "321300": "宿迁市",
            "321302": "宿城区",
            "321311": "宿豫区",
            "321322": "沭阳县",
            "321323": "泗阳县",
            "321324": "泗洪县",
            "321371": "宿迁经济技术开发区",
            "330100": "杭州市",
            "330000": "浙江省",
            "330102": "上城区",
            "330105": "拱墅区",
            "330106": "西湖区",
            "330108": "滨江区",
            "330109": "萧山区",
            "330110": "余杭区",
            "330111": "富阳区",
            "330112": "临安区",
            "330113": "临平区",
            "330114": "钱塘区",
            "330122": "桐庐县",
            "330127": "淳安县",
            "330182": "建德市",
            "330200": "宁波市",
            "330203": "海曙区",
            "330205": "江北区",
            "330206": "北仑区",
            "330211": "镇海区",
            "330212": "鄞州区",
            "330213": "奉化区",
            "330225": "象山县",
            "330226": "宁海县",
            "330281": "余姚市",
            "330282": "慈溪市",
            "330300": "温州市",
            "330302": "鹿城区",
            "330303": "龙湾区",
            "330304": "瓯海区",
            "330305": "洞头区",
            "330324": "永嘉县",
            "330326": "平阳县",
            "330327": "苍南县",
            "330328": "文成县",
            "330329": "泰顺县",
            "330371": "温州经济技术开发区",
            "330381": "瑞安市",
            "330382": "乐清市",
            "330383": "龙港市",
            "330400": "嘉兴市",
            "330402": "南湖区",
            "330411": "秀洲区",
            "330421": "嘉善县",
            "330424": "海盐县",
            "330481": "海宁市",
            "330482": "平湖市",
            "330483": "桐乡市",
            "330500": "湖州市",
            "330502": "吴兴区",
            "330503": "南浔区",
            "330521": "德清县",
            "330522": "长兴县",
            "330523": "安吉县",
            "330600": "绍兴市",
            "330602": "越城区",
            "330603": "柯桥区",
            "330604": "上虞区",
            "330624": "新昌县",
            "330681": "诸暨市",
            "330683": "嵊州市",
            "330700": "金华市",
            "330702": "婺城区",
            "330703": "金东区",
            "330723": "武义县",
            "330726": "浦江县",
            "330727": "磐安县",
            "330781": "兰溪市",
            "330782": "义乌市",
            "330783": "东阳市",
            "330784": "永康市",
            "330800": "衢州市",
            "330802": "柯城区",
            "330803": "衢江区",
            "330822": "常山县",
            "330824": "开化县",
            "330825": "龙游县",
            "330881": "江山市",
            "330900": "舟山市",
            "330902": "定海区",
            "330903": "普陀区",
            "330921": "岱山县",
            "330922": "嵊泗县",
            "331000": "台州市",
            "331002": "椒江区",
            "331003": "黄岩区",
            "331004": "路桥区",
            "331022": "三门县",
            "331023": "天台县",
            "331024": "仙居县",
            "331081": "温岭市",
            "331082": "临海市",
            "331083": "玉环市",
            "331100": "丽水市",
            "331102": "莲都区",
            "331121": "青田县",
            "331122": "缙云县",
            "331123": "遂昌县",
            "331124": "松阳县",
            "331125": "云和县",
            "331126": "庆元县",
            "331127": "景宁畲族自治县",
            "331181": "龙泉市",
            "340100": "合肥市",
            "340000": "安徽省",
            "340102": "瑶海区",
            "340103": "庐阳区",
            "340104": "蜀山区",
            "340111": "包河区",
            "340121": "长丰县",
            "340122": "肥东县",
            "340123": "肥西县",
            "340124": "庐江县",
            "340171": "合肥高新技术产业开发区",
            "340172": "合肥经济技术开发区",
            "340173": "合肥新站高新技术产业开发区",
            "340181": "巢湖市",
            "340200": "芜湖市",
            "340202": "镜湖区",
            "340207": "鸠江区",
            "340209": "弋江区",
            "340210": "湾沚区",
            "340212": "繁昌区",
            "340223": "南陵县",
            "340271": "芜湖经济技术开发区",
            "340272": "安徽芜湖三山经济开发区",
            "340281": "无为市",
            "340300": "蚌埠市",
            "340302": "龙子湖区",
            "340303": "蚌山区",
            "340304": "禹会区",
            "340311": "淮上区",
            "340321": "怀远县",
            "340322": "五河县",
            "340323": "固镇县",
            "340371": "蚌埠市高新技术开发区",
            "340372": "蚌埠市经济开发区",
            "340400": "淮南市",
            "340402": "大通区",
            "340403": "田家庵区",
            "340404": "谢家集区",
            "340405": "八公山区",
            "340406": "潘集区",
            "340421": "凤台县",
            "340422": "寿县",
            "340500": "马鞍山市",
            "340503": "花山区",
            "340504": "雨山区",
            "340506": "博望区",
            "340521": "当涂县",
            "340522": "含山县",
            "340523": "和县",
            "340600": "淮北市",
            "340602": "杜集区",
            "340603": "相山区",
            "340604": "烈山区",
            "340621": "濉溪县",
            "340700": "铜陵市",
            "340705": "铜官区",
            "340706": "义安区",
            "340711": "郊区",
            "340722": "枞阳县",
            "340800": "安庆市",
            "340802": "迎江区",
            "340803": "大观区",
            "340811": "宜秀区",
            "340822": "怀宁县",
            "340825": "太湖县",
            "340826": "宿松县",
            "340827": "望江县",
            "340828": "岳西县",
            "340871": "安徽安庆经济开发区",
            "340881": "桐城市",
            "340882": "潜山市",
            "341000": "黄山市",
            "341002": "屯溪区",
            "341003": "黄山区",
            "341004": "徽州区",
            "341021": "歙县",
            "341022": "休宁县",
            "341023": "黟县",
            "341024": "祁门县",
            "341100": "滁州市",
            "341102": "琅琊区",
            "341103": "南谯区",
            "341122": "来安县",
            "341124": "全椒县",
            "341125": "定远县",
            "341126": "凤阳县",
            "341171": "中新苏滁高新技术产业开发区",
            "341172": "滁州经济技术开发区",
            "341181": "天长市",
            "341182": "明光市",
            "341200": "阜阳市",
            "341202": "颍州区",
            "341203": "颍东区",
            "341204": "颍泉区",
            "341221": "临泉县",
            "341222": "太和县",
            "341225": "阜南县",
            "341226": "颍上县",
            "341271": "阜阳合肥现代产业园区",
            "341272": "阜阳经济技术开发区",
            "341282": "界首市",
            "341300": "宿州市",
            "341302": "埇桥区",
            "341321": "砀山县",
            "341322": "萧县",
            "341323": "灵璧县",
            "341324": "泗县",
            "341371": "宿州马鞍山现代产业园区",
            "341372": "宿州经济技术开发区",
            "341500": "六安市",
            "341502": "金安区",
            "341503": "裕安区",
            "341504": "叶集区",
            "341522": "霍邱县",
            "341523": "舒城县",
            "341524": "金寨县",
            "341525": "霍山县",
            "341600": "亳州市",
            "341602": "谯城区",
            "341621": "涡阳县",
            "341622": "蒙城县",
            "341623": "利辛县",
            "341700": "池州市",
            "341702": "贵池区",
            "341721": "东至县",
            "341722": "石台县",
            "341723": "青阳县",
            "341800": "宣城市",
            "341802": "宣州区",
            "341821": "郎溪县",
            "341823": "泾县",
            "341824": "绩溪县",
            "341825": "旌德县",
            "341871": "宣城市经济开发区",
            "341881": "宁国市",
            "341882": "广德市",
            "350100": "福州市",
            "350000": "福建省",
            "350102": "鼓楼区",
            "350103": "台江区",
            "350104": "仓山区",
            "350105": "马尾区",
            "350111": "晋安区",
            "350112": "长乐区",
            "350121": "闽侯县",
            "350122": "连江县",
            "350123": "罗源县",
            "350124": "闽清县",
            "350125": "永泰县",
            "350128": "平潭县",
            "350181": "福清市",
            "350200": "厦门市",
            "350203": "思明区",
            "350205": "海沧区",
            "350206": "湖里区",
            "350211": "集美区",
            "350212": "同安区",
            "350213": "翔安区",
            "350300": "莆田市",
            "350302": "城厢区",
            "350303": "涵江区",
            "350304": "荔城区",
            "350305": "秀屿区",
            "350322": "仙游县",
            "350400": "三明市",
            "350404": "三元区",
            "350405": "沙县区",
            "350421": "明溪县",
            "350423": "清流县",
            "350424": "宁化县",
            "350425": "大田县",
            "350426": "尤溪县",
            "350428": "将乐县",
            "350429": "泰宁县",
            "350430": "建宁县",
            "350481": "永安市",
            "350500": "泉州市",
            "350502": "鲤城区",
            "350503": "丰泽区",
            "350504": "洛江区",
            "350505": "泉港区",
            "350521": "惠安县",
            "350524": "安溪县",
            "350525": "永春县",
            "350526": "德化县",
            "350581": "石狮市",
            "350582": "晋江市",
            "350583": "南安市",
            "350600": "漳州市",
            "350602": "芗城区",
            "350603": "龙文区",
            "350604": "龙海区",
            "350605": "长泰区",
            "350622": "云霄县",
            "350623": "漳浦县",
            "350624": "诏安县",
            "350626": "东山县",
            "350627": "南靖县",
            "350628": "平和县",
            "350629": "华安县",
            "350700": "南平市",
            "350702": "延平区",
            "350703": "建阳区",
            "350721": "顺昌县",
            "350722": "浦城县",
            "350723": "光泽县",
            "350724": "松溪县",
            "350725": "政和县",
            "350781": "邵武市",
            "350782": "武夷山市",
            "350783": "建瓯市",
            "350800": "龙岩市",
            "350802": "新罗区",
            "350803": "永定区",
            "350821": "长汀县",
            "350823": "上杭县",
            "350824": "武平县",
            "350825": "连城县",
            "350881": "漳平市",
            "350900": "宁德市",
            "350902": "蕉城区",
            "350921": "霞浦县",
            "350922": "古田县",
            "350923": "屏南县",
            "350924": "寿宁县",
            "350925": "周宁县",
            "350926": "柘荣县",
            "350981": "福安市",
            "350982": "福鼎市",
            "360100": "南昌市",
            "360000": "江西省",
            "360102": "东湖区",
            "360103": "西湖区",
            "360104": "青云谱区",
            "360111": "青山湖区",
            "360112": "新建区",
            "360113": "红谷滩区",
            "360121": "南昌县",
            "360123": "安义县",
            "360124": "进贤县",
            "360200": "景德镇市",
            "360202": "昌江区",
            "360203": "珠山区",
            "360222": "浮梁县",
            "360281": "乐平市",
            "360300": "萍乡市",
            "360302": "安源区",
            "360313": "湘东区",
            "360321": "莲花县",
            "360322": "上栗县",
            "360323": "芦溪县",
            "360400": "九江市",
            "360402": "濂溪区",
            "360403": "浔阳区",
            "360404": "柴桑区",
            "360423": "武宁县",
            "360424": "修水县",
            "360425": "永修县",
            "360426": "德安县",
            "360428": "都昌县",
            "360429": "湖口县",
            "360430": "彭泽县",
            "360481": "瑞昌市",
            "360482": "共青城市",
            "360483": "庐山市",
            "360500": "新余市",
            "360502": "渝水区",
            "360521": "分宜县",
            "360600": "鹰潭市",
            "360602": "月湖区",
            "360603": "余江区",
            "360681": "贵溪市",
            "360700": "赣州市",
            "360702": "章贡区",
            "360703": "南康区",
            "360704": "赣县区",
            "360722": "信丰县",
            "360723": "大余县",
            "360724": "上犹县",
            "360725": "崇义县",
            "360726": "安远县",
            "360728": "定南县",
            "360729": "全南县",
            "360730": "宁都县",
            "360731": "于都县",
            "360732": "兴国县",
            "360733": "会昌县",
            "360734": "寻乌县",
            "360735": "石城县",
            "360781": "瑞金市",
            "360783": "龙南市",
            "360800": "吉安市",
            "360802": "吉州区",
            "360803": "青原区",
            "360821": "吉安县",
            "360822": "吉水县",
            "360823": "峡江县",
            "360824": "新干县",
            "360825": "永丰县",
            "360826": "泰和县",
            "360827": "遂川县",
            "360828": "万安县",
            "360829": "安福县",
            "360830": "永新县",
            "360881": "井冈山市",
            "360900": "宜春市",
            "360902": "袁州区",
            "360921": "奉新县",
            "360922": "万载县",
            "360923": "上高县",
            "360924": "宜丰县",
            "360925": "靖安县",
            "360926": "铜鼓县",
            "360981": "丰城市",
            "360982": "樟树市",
            "360983": "高安市",
            "361000": "抚州市",
            "361002": "临川区",
            "361003": "东乡区",
            "361021": "南城县",
            "361022": "黎川县",
            "361023": "南丰县",
            "361024": "崇仁县",
            "361025": "乐安县",
            "361026": "宜黄县",
            "361027": "金溪县",
            "361028": "资溪县",
            "361030": "广昌县",
            "361100": "上饶市",
            "361102": "信州区",
            "361103": "广丰区",
            "361104": "广信区",
            "361123": "玉山县",
            "361124": "铅山县",
            "361125": "横峰县",
            "361126": "弋阳县",
            "361127": "余干县",
            "361128": "鄱阳县",
            "361129": "万年县",
            "361130": "婺源县",
            "361181": "德兴市",
            "370100": "济南市",
            "370000": "山东省",
            "370102": "历下区",
            "370103": "市中区",
            "370104": "槐荫区",
            "370105": "天桥区",
            "370112": "历城区",
            "370113": "长清区",
            "370114": "章丘区",
            "370115": "济阳区",
            "370116": "莱芜区",
            "370117": "钢城区",
            "370124": "平阴县",
            "370126": "商河县",
            "370171": "济南高新技术产业开发区",
            "370200": "青岛市",
            "370202": "市南区",
            "370203": "市北区",
            "370211": "黄岛区",
            "370212": "崂山区",
            "370213": "李沧区",
            "370214": "城阳区",
            "370215": "即墨区",
            "370271": "青岛高新技术产业开发区",
            "370281": "胶州市",
            "370283": "平度市",
            "370285": "莱西市",
            "370300": "淄博市",
            "370302": "淄川区",
            "370303": "张店区",
            "370304": "博山区",
            "370305": "临淄区",
            "370306": "周村区",
            "370321": "桓台县",
            "370322": "高青县",
            "370323": "沂源县",
            "370400": "枣庄市",
            "370402": "市中区",
            "370403": "薛城区",
            "370404": "峄城区",
            "370405": "台儿庄区",
            "370406": "山亭区",
            "370481": "滕州市",
            "370500": "东营市",
            "370502": "东营区",
            "370503": "河口区",
            "370505": "垦利区",
            "370522": "利津县",
            "370523": "广饶县",
            "370571": "东营经济技术开发区",
            "370572": "东营港经济开发区",
            "370600": "烟台市",
            "370602": "芝罘区",
            "370611": "福山区",
            "370612": "牟平区",
            "370613": "莱山区",
            "370614": "蓬莱区",
            "370671": "烟台高新技术产业开发区",
            "370672": "烟台经济技术开发区",
            "370681": "龙口市",
            "370682": "莱阳市",
            "370683": "莱州市",
            "370685": "招远市",
            "370686": "栖霞市",
            "370687": "海阳市",
            "370700": "潍坊市",
            "370702": "潍城区",
            "370703": "寒亭区",
            "370704": "坊子区",
            "370705": "奎文区",
            "370724": "临朐县",
            "370725": "昌乐县",
            "370772": "潍坊滨海经济技术开发区",
            "370781": "青州市",
            "370782": "诸城市",
            "370783": "寿光市",
            "370784": "安丘市",
            "370785": "高密市",
            "370786": "昌邑市",
            "370800": "济宁市",
            "370811": "任城区",
            "370812": "兖州区",
            "370826": "微山县",
            "370827": "鱼台县",
            "370828": "金乡县",
            "370829": "嘉祥县",
            "370830": "汶上县",
            "370831": "泗水县",
            "370832": "梁山县",
            "370871": "济宁高新技术产业开发区",
            "370881": "曲阜市",
            "370883": "邹城市",
            "370900": "泰安市",
            "370902": "泰山区",
            "370911": "岱岳区",
            "370921": "宁阳县",
            "370923": "东平县",
            "370982": "新泰市",
            "370983": "肥城市",
            "371000": "威海市",
            "371002": "环翠区",
            "371003": "文登区",
            "371071": "威海火炬高技术产业开发区",
            "371072": "威海经济技术开发区",
            "371073": "威海临港经济技术开发区",
            "371082": "荣成市",
            "371083": "乳山市",
            "371100": "日照市",
            "371102": "东港区",
            "371103": "岚山区",
            "371121": "五莲县",
            "371122": "莒县",
            "371171": "日照经济技术开发区",
            "371300": "临沂市",
            "371302": "兰山区",
            "371311": "罗庄区",
            "371312": "河东区",
            "371321": "沂南县",
            "371322": "郯城县",
            "371323": "沂水县",
            "371324": "兰陵县",
            "371325": "费县",
            "371326": "平邑县",
            "371327": "莒南县",
            "371328": "蒙阴县",
            "371329": "临沭县",
            "371371": "临沂高新技术产业开发区",
            "371400": "德州市",
            "371402": "德城区",
            "371403": "陵城区",
            "371422": "宁津县",
            "371423": "庆云县",
            "371424": "临邑县",
            "371425": "齐河县",
            "371426": "平原县",
            "371427": "夏津县",
            "371428": "武城县",
            "371471": "德州经济技术开发区",
            "371472": "德州运河经济开发区",
            "371481": "乐陵市",
            "371482": "禹城市",
            "371500": "聊城市",
            "371502": "东昌府区",
            "371503": "茌平区",
            "371521": "阳谷县",
            "371522": "莘县",
            "371524": "东阿县",
            "371525": "冠县",
            "371526": "高唐县",
            "371581": "临清市",
            "371600": "滨州市",
            "371602": "滨城区",
            "371603": "沾化区",
            "371621": "惠民县",
            "371622": "阳信县",
            "371623": "无棣县",
            "371625": "博兴县",
            "371681": "邹平市",
            "371700": "菏泽市",
            "371702": "牡丹区",
            "371703": "定陶区",
            "371721": "曹县",
            "371722": "单县",
            "371723": "成武县",
            "371724": "巨野县",
            "371725": "郓城县",
            "371726": "鄄城县",
            "371728": "东明县",
            "371771": "菏泽经济技术开发区",
            "371772": "菏泽高新技术开发区",
            "410100": "郑州市",
            "410000": "河南省",
            "410102": "中原区",
            "410103": "二七区",
            "410104": "管城回族区",
            "410105": "金水区",
            "410106": "上街区",
            "410108": "惠济区",
            "410122": "中牟县",
            "410171": "郑州经济技术开发区",
            "410172": "郑州高新技术产业开发区",
            "410173": "郑州航空港经济综合实验区",
            "410181": "巩义市",
            "410182": "荥阳市",
            "410183": "新密市",
            "410184": "新郑市",
            "410185": "登封市",
            "410200": "开封市",
            "410202": "龙亭区",
            "410203": "顺河回族区",
            "410204": "鼓楼区",
            "410205": "禹王台区",
            "410212": "祥符区",
            "410221": "杞县",
            "410222": "通许县",
            "410223": "尉氏县",
            "410225": "兰考县",
            "410300": "洛阳市",
            "410302": "老城区",
            "410303": "西工区",
            "410304": "瀍河回族区",
            "410305": "涧西区",
            "410307": "偃师区",
            "410308": "孟津区",
            "410311": "洛龙区",
            "410323": "新安县",
            "410324": "栾川县",
            "410325": "嵩县",
            "410326": "汝阳县",
            "410327": "宜阳县",
            "410328": "洛宁县",
            "410329": "伊川县",
            "410371": "洛阳高新技术产业开发区",
            "410400": "平顶山市",
            "410402": "新华区",
            "410403": "卫东区",
            "410404": "石龙区",
            "410411": "湛河区",
            "410421": "宝丰县",
            "410422": "叶县",
            "410423": "鲁山县",
            "410425": "郏县",
            "410471": "平顶山高新技术产业开发区",
            "410472": "平顶山市城乡一体化示范区",
            "410481": "舞钢市",
            "410482": "汝州市",
            "410500": "安阳市",
            "410502": "文峰区",
            "410503": "北关区",
            "410505": "殷都区",
            "410506": "龙安区",
            "410522": "安阳县",
            "410523": "汤阴县",
            "410526": "滑县",
            "410527": "内黄县",
            "410571": "安阳高新技术产业开发区",
            "410581": "林州市",
            "410600": "鹤壁市",
            "410602": "鹤山区",
            "410603": "山城区",
            "410611": "淇滨区",
            "410621": "浚县",
            "410622": "淇县",
            "410671": "鹤壁经济技术开发区",
            "410700": "新乡市",
            "410702": "红旗区",
            "410703": "卫滨区",
            "410704": "凤泉区",
            "410711": "牧野区",
            "410721": "新乡县",
            "410724": "获嘉县",
            "410725": "原阳县",
            "410726": "延津县",
            "410727": "封丘县",
            "410771": "新乡高新技术产业开发区",
            "410772": "新乡经济技术开发区",
            "410773": "新乡市平原城乡一体化示范区",
            "410781": "卫辉市",
            "410782": "辉县市",
            "410783": "长垣市",
            "410800": "焦作市",
            "410802": "解放区",
            "410803": "中站区",
            "410804": "马村区",
            "410811": "山阳区",
            "410821": "修武县",
            "410822": "博爱县",
            "410823": "武陟县",
            "410825": "温县",
            "410871": "焦作城乡一体化示范区",
            "410882": "沁阳市",
            "410883": "孟州市",
            "410900": "濮阳市",
            "410902": "华龙区",
            "410922": "清丰县",
            "410923": "南乐县",
            "410926": "范县",
            "410927": "台前县",
            "410928": "濮阳县",
            "410971": "河南濮阳工业园区",
            "410972": "濮阳经济技术开发区",
            "411000": "许昌市",
            "411002": "魏都区",
            "411003": "建安区",
            "411024": "鄢陵县",
            "411025": "襄城县",
            "411071": "许昌经济技术开发区",
            "411081": "禹州市",
            "411082": "长葛市",
            "411100": "漯河市",
            "411102": "源汇区",
            "411103": "郾城区",
            "411104": "召陵区",
            "411121": "舞阳县",
            "411122": "临颍县",
            "411171": "漯河经济技术开发区",
            "411200": "三门峡市",
            "411202": "湖滨区",
            "411203": "陕州区",
            "411221": "渑池县",
            "411224": "卢氏县",
            "411271": "河南三门峡经济开发区",
            "411281": "义马市",
            "411282": "灵宝市",
            "411300": "南阳市",
            "411302": "宛城区",
            "411303": "卧龙区",
            "411321": "南召县",
            "411322": "方城县",
            "411323": "西峡县",
            "411324": "镇平县",
            "411325": "内乡县",
            "411326": "淅川县",
            "411327": "社旗县",
            "411328": "唐河县",
            "411329": "新野县",
            "411330": "桐柏县",
            "411371": "南阳高新技术产业开发区",
            "411372": "南阳市城乡一体化示范区",
            "411381": "邓州市",
            "411400": "商丘市",
            "411402": "梁园区",
            "411403": "睢阳区",
            "411421": "民权县",
            "411422": "睢县",
            "411423": "宁陵县",
            "411424": "柘城县",
            "411425": "虞城县",
            "411426": "夏邑县",
            "411471": "豫东综合物流产业聚集区",
            "411472": "河南商丘经济开发区",
            "411481": "永城市",
            "411500": "信阳市",
            "411502": "浉河区",
            "411503": "平桥区",
            "411521": "罗山县",
            "411522": "光山县",
            "411523": "新县",
            "411524": "商城县",
            "411525": "固始县",
            "411526": "潢川县",
            "411527": "淮滨县",
            "411528": "息县",
            "411571": "信阳高新技术产业开发区",
            "411600": "周口市",
            "411602": "川汇区",
            "411603": "淮阳区",
            "411621": "扶沟县",
            "411622": "西华县",
            "411623": "商水县",
            "411624": "沈丘县",
            "411625": "郸城县",
            "411627": "太康县",
            "411628": "鹿邑县",
            "411671": "河南周口经济开发区",
            "411681": "项城市",
            "411700": "驻马店市",
            "411702": "驿城区",
            "411721": "西平县",
            "411722": "上蔡县",
            "411723": "平舆县",
            "411724": "正阳县",
            "411725": "确山县",
            "411726": "泌阳县",
            "411727": "汝南县",
            "411728": "遂平县",
            "411729": "新蔡县",
            "411771": "河南驻马店经济开发区",
            "419001": "济源市",
            "420100": "武汉市",
            "420000": "湖北省",
            "420102": "江岸区",
            "420103": "江汉区",
            "420104": "硚口区",
            "420105": "汉阳区",
            "420106": "武昌区",
            "420107": "青山区",
            "420111": "洪山区",
            "420112": "东西湖区",
            "420113": "汉南区",
            "420114": "蔡甸区",
            "420115": "江夏区",
            "420116": "黄陂区",
            "420117": "新洲区",
            "420200": "黄石市",
            "420202": "黄石港区",
            "420203": "西塞山区",
            "420204": "下陆区",
            "420205": "铁山区",
            "420222": "阳新县",
            "420281": "大冶市",
            "420300": "十堰市",
            "420302": "茅箭区",
            "420303": "张湾区",
            "420304": "郧阳区",
            "420322": "郧西县",
            "420323": "竹山县",
            "420324": "竹溪县",
            "420325": "房县",
            "420381": "丹江口市",
            "420500": "宜昌市",
            "420502": "西陵区",
            "420503": "伍家岗区",
            "420504": "点军区",
            "420505": "猇亭区",
            "420506": "夷陵区",
            "420525": "远安县",
            "420526": "兴山县",
            "420527": "秭归县",
            "420528": "长阳土家族自治县",
            "420529": "五峰土家族自治县",
            "420581": "宜都市",
            "420582": "当阳市",
            "420583": "枝江市",
            "420600": "襄阳市",
            "420602": "襄城区",
            "420606": "樊城区",
            "420607": "襄州区",
            "420624": "南漳县",
            "420625": "谷城县",
            "420626": "保康县",
            "420682": "老河口市",
            "420683": "枣阳市",
            "420684": "宜城市",
            "420700": "鄂州市",
            "420702": "梁子湖区",
            "420703": "华容区",
            "420704": "鄂城区",
            "420800": "荆门市",
            "420802": "东宝区",
            "420804": "掇刀区",
            "420822": "沙洋县",
            "420881": "钟祥市",
            "420882": "京山市",
            "420900": "孝感市",
            "420902": "孝南区",
            "420921": "孝昌县",
            "420922": "大悟县",
            "420923": "云梦县",
            "420981": "应城市",
            "420982": "安陆市",
            "420984": "汉川市",
            "421000": "荆州市",
            "421002": "沙市区",
            "421003": "荆州区",
            "421022": "公安县",
            "421024": "江陵县",
            "421071": "荆州经济技术开发区",
            "421081": "石首市",
            "421083": "洪湖市",
            "421087": "松滋市",
            "421088": "监利市",
            "421100": "黄冈市",
            "421102": "黄州区",
            "421121": "团风县",
            "421122": "红安县",
            "421123": "罗田县",
            "421124": "英山县",
            "421125": "浠水县",
            "421126": "蕲春县",
            "421127": "黄梅县",
            "421171": "龙感湖管理区",
            "421181": "麻城市",
            "421182": "武穴市",
            "421200": "咸宁市",
            "421202": "咸安区",
            "421221": "嘉鱼县",
            "421222": "通城县",
            "421223": "崇阳县",
            "421224": "通山县",
            "421281": "赤壁市",
            "421300": "随州市",
            "421303": "曾都区",
            "421321": "随县",
            "421381": "广水市",
            "422800": "恩施土家族苗族自治州",
            "422801": "恩施市",
            "422802": "利川市",
            "422822": "建始县",
            "422823": "巴东县",
            "422825": "宣恩县",
            "422826": "咸丰县",
            "422827": "来凤县",
            "422828": "鹤峰县",
            "429004": "仙桃市",
            "429005": "潜江市",
            "429006": "天门市",
            "429021": "神农架林区",
            "430100": "长沙市",
            "430000": "湖南省",
            "430102": "芙蓉区",
            "430103": "天心区",
            "430104": "岳麓区",
            "430105": "开福区",
            "430111": "雨花区",
            "430112": "望城区",
            "430121": "长沙县",
            "430181": "浏阳市",
            "430182": "宁乡市",
            "430200": "株洲市",
            "430202": "荷塘区",
            "430203": "芦淞区",
            "430204": "石峰区",
            "430211": "天元区",
            "430212": "渌口区",
            "430223": "攸县",
            "430224": "茶陵县",
            "430225": "炎陵县",
            "430271": "云龙示范区",
            "430281": "醴陵市",
            "430300": "湘潭市",
            "430302": "雨湖区",
            "430304": "岳塘区",
            "430321": "湘潭县",
            "430371": "湖南湘潭高新技术产业园区",
            "430372": "湘潭昭山示范区",
            "430373": "湘潭九华示范区",
            "430381": "湘乡市",
            "430382": "韶山市",
            "430400": "衡阳市",
            "430405": "珠晖区",
            "430406": "雁峰区",
            "430407": "石鼓区",
            "430408": "蒸湘区",
            "430412": "南岳区",
            "430421": "衡阳县",
            "430422": "衡南县",
            "430423": "衡山县",
            "430424": "衡东县",
            "430426": "祁东县",
            "430471": "衡阳综合保税区",
            "430472": "湖南衡阳高新技术产业园区",
            "430473": "湖南衡阳松木经济开发区",
            "430481": "耒阳市",
            "430482": "常宁市",
            "430500": "邵阳市",
            "430502": "双清区",
            "430503": "大祥区",
            "430511": "北塔区",
            "430522": "新邵县",
            "430523": "邵阳县",
            "430524": "隆回县",
            "430525": "洞口县",
            "430527": "绥宁县",
            "430528": "新宁县",
            "430529": "城步苗族自治县",
            "430581": "武冈市",
            "430582": "邵东市",
            "430600": "岳阳市",
            "430602": "岳阳楼区",
            "430603": "云溪区",
            "430611": "君山区",
            "430621": "岳阳县",
            "430623": "华容县",
            "430624": "湘阴县",
            "430626": "平江县",
            "430671": "岳阳市屈原管理区",
            "430681": "汨罗市",
            "430682": "临湘市",
            "430700": "常德市",
            "430702": "武陵区",
            "430703": "鼎城区",
            "430721": "安乡县",
            "430722": "汉寿县",
            "430723": "澧县",
            "430724": "临澧县",
            "430725": "桃源县",
            "430726": "石门县",
            "430771": "常德市西洞庭管理区",
            "430781": "津市市",
            "430800": "张家界市",
            "430802": "永定区",
            "430811": "武陵源区",
            "430821": "慈利县",
            "430822": "桑植县",
            "430900": "益阳市",
            "430902": "资阳区",
            "430903": "赫山区",
            "430921": "南县",
            "430922": "桃江县",
            "430923": "安化县",
            "430971": "益阳市大通湖管理区",
            "430972": "湖南益阳高新技术产业园区",
            "430981": "沅江市",
            "431000": "郴州市",
            "431002": "北湖区",
            "431003": "苏仙区",
            "431021": "桂阳县",
            "431022": "宜章县",
            "431023": "永兴县",
            "431024": "嘉禾县",
            "431025": "临武县",
            "431026": "汝城县",
            "431027": "桂东县",
            "431028": "安仁县",
            "431081": "资兴市",
            "431100": "永州市",
            "431102": "零陵区",
            "431103": "冷水滩区",
            "431122": "东安县",
            "431123": "双牌县",
            "431124": "道县",
            "431125": "江永县",
            "431126": "宁远县",
            "431127": "蓝山县",
            "431128": "新田县",
            "431129": "江华瑶族自治县",
            "431171": "永州经济技术开发区",
            "431173": "永州市回龙圩管理区",
            "431181": "祁阳市",
            "431200": "怀化市",
            "431202": "鹤城区",
            "431221": "中方县",
            "431222": "沅陵县",
            "431223": "辰溪县",
            "431224": "溆浦县",
            "431225": "会同县",
            "431226": "麻阳苗族自治县",
            "431227": "新晃侗族自治县",
            "431228": "芷江侗族自治县",
            "431229": "靖州苗族侗族自治县",
            "431230": "通道侗族自治县",
            "431271": "怀化市洪江管理区",
            "431281": "洪江市",
            "431300": "娄底市",
            "431302": "娄星区",
            "431321": "双峰县",
            "431322": "新化县",
            "431381": "冷水江市",
            "431382": "涟源市",
            "433100": "湘西土家族苗族自治州",
            "433101": "吉首市",
            "433122": "泸溪县",
            "433123": "凤凰县",
            "433124": "花垣县",
            "433125": "保靖县",
            "433126": "古丈县",
            "433127": "永顺县",
            "433130": "龙山县",
            "440100": "广州市",
            "440000": "广东省",
            "440103": "荔湾区",
            "440104": "越秀区",
            "440105": "海珠区",
            "440106": "天河区",
            "440111": "白云区",
            "440112": "黄埔区",
            "440113": "番禺区",
            "440114": "花都区",
            "440115": "南沙区",
            "440117": "从化区",
            "440118": "增城区",
            "440200": "韶关市",
            "440203": "武江区",
            "440204": "浈江区",
            "440205": "曲江区",
            "440222": "始兴县",
            "440224": "仁化县",
            "440229": "翁源县",
            "440232": "乳源瑶族自治县",
            "440233": "新丰县",
            "440281": "乐昌市",
            "440282": "南雄市",
            "440300": "深圳市",
            "440303": "罗湖区",
            "440304": "福田区",
            "440305": "南山区",
            "440306": "宝安区",
            "440307": "龙岗区",
            "440308": "盐田区",
            "440309": "龙华区",
            "440310": "坪山区",
            "440311": "光明区",
            "440400": "珠海市",
            "440402": "香洲区",
            "440403": "斗门区",
            "440404": "金湾区",
            "440500": "汕头市",
            "440507": "龙湖区",
            "440511": "金平区",
            "440512": "濠江区",
            "440513": "潮阳区",
            "440514": "潮南区",
            "440515": "澄海区",
            "440523": "南澳县",
            "440600": "佛山市",
            "440604": "禅城区",
            "440605": "南海区",
            "440606": "顺德区",
            "440607": "三水区",
            "440608": "高明区",
            "440700": "江门市",
            "440703": "蓬江区",
            "440704": "江海区",
            "440705": "新会区",
            "440781": "台山市",
            "440783": "开平市",
            "440784": "鹤山市",
            "440785": "恩平市",
            "440800": "湛江市",
            "440802": "赤坎区",
            "440803": "霞山区",
            "440804": "坡头区",
            "440811": "麻章区",
            "440823": "遂溪县",
            "440825": "徐闻县",
            "440881": "廉江市",
            "440882": "雷州市",
            "440883": "吴川市",
            "440900": "茂名市",
            "440902": "茂南区",
            "440904": "电白区",
            "440981": "高州市",
            "440982": "化州市",
            "440983": "信宜市",
            "441200": "肇庆市",
            "441202": "端州区",
            "441203": "鼎湖区",
            "441204": "高要区",
            "441223": "广宁县",
            "441224": "怀集县",
            "441225": "封开县",
            "441226": "德庆县",
            "441284": "四会市",
            "441300": "惠州市",
            "441302": "惠城区",
            "441303": "惠阳区",
            "441322": "博罗县",
            "441323": "惠东县",
            "441324": "龙门县",
            "441400": "梅州市",
            "441402": "梅江区",
            "441403": "梅县区",
            "441422": "大埔县",
            "441423": "丰顺县",
            "441424": "五华县",
            "441426": "平远县",
            "441427": "蕉岭县",
            "441481": "兴宁市",
            "441500": "汕尾市",
            "441502": "城区",
            "441521": "海丰县",
            "441523": "陆河县",
            "441581": "陆丰市",
            "441600": "河源市",
            "441602": "源城区",
            "441621": "紫金县",
            "441622": "龙川县",
            "441623": "连平县",
            "441624": "和平县",
            "441625": "东源县",
            "441700": "阳江市",
            "441702": "江城区",
            "441704": "阳东区",
            "441721": "阳西县",
            "441781": "阳春市",
            "441800": "清远市",
            "441802": "清城区",
            "441803": "清新区",
            "441821": "佛冈县",
            "441823": "阳山县",
            "441825": "连山壮族瑶族自治县",
            "441826": "连南瑶族自治县",
            "441881": "英德市",
            "441882": "连州市",
            "441900": "东莞市",
            "442000": "中山市",
            "445100": "潮州市",
            "445102": "湘桥区",
            "445103": "潮安区",
            "445122": "饶平县",
            "445200": "揭阳市",
            "445202": "榕城区",
            "445203": "揭东区",
            "445222": "揭西县",
            "445224": "惠来县",
            "445281": "普宁市",
            "445300": "云浮市",
            "445302": "云城区",
            "445303": "云安区",
            "445321": "新兴县",
            "445322": "郁南县",
            "445381": "罗定市",
            "450100": "南宁市",
            "450000": "广西壮族自治区",
            "450102": "兴宁区",
            "450103": "青秀区",
            "450105": "江南区",
            "450107": "西乡塘区",
            "450108": "良庆区",
            "450109": "邕宁区",
            "450110": "武鸣区",
            "450123": "隆安县",
            "450124": "马山县",
            "450125": "上林县",
            "450126": "宾阳县",
            "450181": "横州市",
            "450200": "柳州市",
            "450202": "城中区",
            "450203": "鱼峰区",
            "450204": "柳南区",
            "450205": "柳北区",
            "450206": "柳江区",
            "450222": "柳城县",
            "450223": "鹿寨县",
            "450224": "融安县",
            "450225": "融水苗族自治县",
            "450226": "三江侗族自治县",
            "450300": "桂林市",
            "450302": "秀峰区",
            "450303": "叠彩区",
            "450304": "象山区",
            "450305": "七星区",
            "450311": "雁山区",
            "450312": "临桂区",
            "450321": "阳朔县",
            "450323": "灵川县",
            "450324": "全州县",
            "450325": "兴安县",
            "450326": "永福县",
            "450327": "灌阳县",
            "450328": "龙胜各族自治县",
            "450329": "资源县",
            "450330": "平乐县",
            "450332": "恭城瑶族自治县",
            "450381": "荔浦市",
            "450400": "梧州市",
            "450403": "万秀区",
            "450405": "长洲区",
            "450406": "龙圩区",
            "450421": "苍梧县",
            "450422": "藤县",
            "450423": "蒙山县",
            "450481": "岑溪市",
            "450500": "北海市",
            "450502": "海城区",
            "450503": "银海区",
            "450512": "铁山港区",
            "450521": "合浦县",
            "450600": "防城港市",
            "450602": "港口区",
            "450603": "防城区",
            "450621": "上思县",
            "450681": "东兴市",
            "450700": "钦州市",
            "450702": "钦南区",
            "450703": "钦北区",
            "450721": "灵山县",
            "450722": "浦北县",
            "450800": "贵港市",
            "450802": "港北区",
            "450803": "港南区",
            "450804": "覃塘区",
            "450821": "平南县",
            "450881": "桂平市",
            "450900": "玉林市",
            "450902": "玉州区",
            "450903": "福绵区",
            "450921": "容县",
            "450922": "陆川县",
            "450923": "博白县",
            "450924": "兴业县",
            "450981": "北流市",
            "451000": "百色市",
            "451002": "右江区",
            "451003": "田阳区",
            "451022": "田东县",
            "451024": "德保县",
            "451026": "那坡县",
            "451027": "凌云县",
            "451028": "乐业县",
            "451029": "田林县",
            "451030": "西林县",
            "451031": "隆林各族自治县",
            "451081": "靖西市",
            "451082": "平果市",
            "451100": "贺州市",
            "451102": "八步区",
            "451103": "平桂区",
            "451121": "昭平县",
            "451122": "钟山县",
            "451123": "富川瑶族自治县",
            "451200": "河池市",
            "451202": "金城江区",
            "451203": "宜州区",
            "451221": "南丹县",
            "451222": "天峨县",
            "451223": "凤山县",
            "451224": "东兰县",
            "451225": "罗城仫佬族自治县",
            "451226": "环江毛南族自治县",
            "451227": "巴马瑶族自治县",
            "451228": "都安瑶族自治县",
            "451229": "大化瑶族自治县",
            "451300": "来宾市",
            "451302": "兴宾区",
            "451321": "忻城县",
            "451322": "象州县",
            "451323": "武宣县",
            "451324": "金秀瑶族自治县",
            "451381": "合山市",
            "451400": "崇左市",
            "451402": "江州区",
            "451421": "扶绥县",
            "451422": "宁明县",
            "451423": "龙州县",
            "451424": "大新县",
            "451425": "天等县",
            "451481": "凭祥市",
            "460100": "海口市",
            "460000": "海南省",
            "460105": "秀英区",
            "460106": "龙华区",
            "460107": "琼山区",
            "460108": "美兰区",
            "460200": "三亚市",
            "460202": "海棠区",
            "460203": "吉阳区",
            "460204": "天涯区",
            "460205": "崖州区",
            "460300": "三沙市",
            "460321": "西沙群岛",
            "460322": "南沙群岛",
            "460323": "中沙群岛的岛礁及其海域",
            "460400": "儋州市",
            "469001": "五指山市",
            "469002": "琼海市",
            "469005": "文昌市",
            "469006": "万宁市",
            "469007": "东方市",
            "469021": "定安县",
            "469022": "屯昌县",
            "469023": "澄迈县",
            "469024": "临高县",
            "469025": "白沙黎族自治县",
            "469026": "昌江黎族自治县",
            "469027": "乐东黎族自治县",
            "469028": "陵水黎族自治县",
            "469029": "保亭黎族苗族自治县",
            "469030": "琼中黎族苗族自治县",
            "500000": "重庆市",
            "500101": "万州区",
            "500102": "涪陵区",
            "500103": "渝中区",
            "500104": "大渡口区",
            "500105": "江北区",
            "500106": "沙坪坝区",
            "500107": "九龙坡区",
            "500108": "南岸区",
            "500109": "北碚区",
            "500110": "綦江区",
            "500111": "大足区",
            "500112": "渝北区",
            "500113": "巴南区",
            "500114": "黔江区",
            "500115": "长寿区",
            "500116": "江津区",
            "500117": "合川区",
            "500118": "永川区",
            "500119": "南川区",
            "500120": "璧山区",
            "500151": "铜梁区",
            "500152": "潼南区",
            "500153": "荣昌区",
            "500154": "开州区",
            "500155": "梁平区",
            "500156": "武隆区",
            "500229": "城口县",
            "500230": "丰都县",
            "500231": "垫江县",
            "500233": "忠县",
            "500235": "云阳县",
            "500236": "奉节县",
            "500237": "巫山县",
            "500238": "巫溪县",
            "500240": "石柱土家族自治县",
            "500241": "秀山土家族苗族自治县",
            "500242": "酉阳土家族苗族自治县",
            "500243": "彭水苗族土家族自治县",
            "510100": "成都市",
            "510000": "四川省",
            "510104": "锦江区",
            "510105": "青羊区",
            "510106": "金牛区",
            "510107": "武侯区",
            "510108": "成华区",
            "510112": "龙泉驿区",
            "510113": "青白江区",
            "510114": "新都区",
            "510115": "温江区",
            "510116": "双流区",
            "510117": "郫都区",
            "510118": "新津区",
            "510121": "金堂县",
            "510129": "大邑县",
            "510131": "蒲江县",
            "510181": "都江堰市",
            "510182": "彭州市",
            "510183": "邛崃市",
            "510184": "崇州市",
            "510185": "简阳市",
            "510300": "自贡市",
            "510302": "自流井区",
            "510303": "贡井区",
            "510304": "大安区",
            "510311": "沿滩区",
            "510321": "荣县",
            "510322": "富顺县",
            "510400": "攀枝花市",
            "510402": "东区",
            "510403": "西区",
            "510411": "仁和区",
            "510421": "米易县",
            "510422": "盐边县",
            "510500": "泸州市",
            "510502": "江阳区",
            "510503": "纳溪区",
            "510504": "龙马潭区",
            "510521": "泸县",
            "510522": "合江县",
            "510524": "叙永县",
            "510525": "古蔺县",
            "510600": "德阳市",
            "510603": "旌阳区",
            "510604": "罗江区",
            "510623": "中江县",
            "510681": "广汉市",
            "510682": "什邡市",
            "510683": "绵竹市",
            "510700": "绵阳市",
            "510703": "涪城区",
            "510704": "游仙区",
            "510705": "安州区",
            "510722": "三台县",
            "510723": "盐亭县",
            "510725": "梓潼县",
            "510726": "北川羌族自治县",
            "510727": "平武县",
            "510781": "江油市",
            "510800": "广元市",
            "510802": "利州区",
            "510811": "昭化区",
            "510812": "朝天区",
            "510821": "旺苍县",
            "510822": "青川县",
            "510823": "剑阁县",
            "510824": "苍溪县",
            "510900": "遂宁市",
            "510903": "船山区",
            "510904": "安居区",
            "510921": "蓬溪县",
            "510923": "大英县",
            "510981": "射洪市",
            "511000": "内江市",
            "511002": "市中区",
            "511011": "东兴区",
            "511024": "威远县",
            "511025": "资中县",
            "511071": "内江经济开发区",
            "511083": "隆昌市",
            "511100": "乐山市",
            "511102": "市中区",
            "511111": "沙湾区",
            "511112": "五通桥区",
            "511113": "金口河区",
            "511123": "犍为县",
            "511124": "井研县",
            "511126": "夹江县",
            "511129": "沐川县",
            "511132": "峨边彝族自治县",
            "511133": "马边彝族自治县",
            "511181": "峨眉山市",
            "511300": "南充市",
            "511302": "顺庆区",
            "511303": "高坪区",
            "511304": "嘉陵区",
            "511321": "南部县",
            "511322": "营山县",
            "511323": "蓬安县",
            "511324": "仪陇县",
            "511325": "西充县",
            "511381": "阆中市",
            "511400": "眉山市",
            "511402": "东坡区",
            "511403": "彭山区",
            "511421": "仁寿县",
            "511423": "洪雅县",
            "511424": "丹棱县",
            "511425": "青神县",
            "511500": "宜宾市",
            "511502": "翠屏区",
            "511503": "南溪区",
            "511504": "叙州区",
            "511523": "江安县",
            "511524": "长宁县",
            "511525": "高县",
            "511526": "珙县",
            "511527": "筠连县",
            "511528": "兴文县",
            "511529": "屏山县",
            "511600": "广安市",
            "511602": "广安区",
            "511603": "前锋区",
            "511621": "岳池县",
            "511622": "武胜县",
            "511623": "邻水县",
            "511681": "华蓥市",
            "511700": "达州市",
            "511702": "通川区",
            "511703": "达川区",
            "511722": "宣汉县",
            "511723": "开江县",
            "511724": "大竹县",
            "511725": "渠县",
            "511771": "达州经济开发区",
            "511781": "万源市",
            "511800": "雅安市",
            "511802": "雨城区",
            "511803": "名山区",
            "511822": "荥经县",
            "511823": "汉源县",
            "511824": "石棉县",
            "511825": "天全县",
            "511826": "芦山县",
            "511827": "宝兴县",
            "511900": "巴中市",
            "511902": "巴州区",
            "511903": "恩阳区",
            "511921": "通江县",
            "511922": "南江县",
            "511923": "平昌县",
            "511971": "巴中经济开发区",
            "512000": "资阳市",
            "512002": "雁江区",
            "512021": "安岳县",
            "512022": "乐至县",
            "513200": "阿坝藏族羌族自治州",
            "513201": "马尔康市",
            "513221": "汶川县",
            "513222": "理县",
            "513223": "茂县",
            "513224": "松潘县",
            "513225": "九寨沟县",
            "513226": "金川县",
            "513227": "小金县",
            "513228": "黑水县",
            "513230": "壤塘县",
            "513231": "阿坝县",
            "513232": "若尔盖县",
            "513233": "红原县",
            "513300": "甘孜藏族自治州",
            "513301": "康定市",
            "513322": "泸定县",
            "513323": "丹巴县",
            "513324": "九龙县",
            "513325": "雅江县",
            "513326": "道孚县",
            "513327": "炉霍县",
            "513328": "甘孜县",
            "513329": "新龙县",
            "513330": "德格县",
            "513331": "白玉县",
            "513332": "石渠县",
            "513333": "色达县",
            "513334": "理塘县",
            "513335": "巴塘县",
            "513336": "乡城县",
            "513337": "稻城县",
            "513338": "得荣县",
            "513400": "凉山彝族自治州",
            "513401": "西昌市",
            "513402": "会理市",
            "513422": "木里藏族自治县",
            "513423": "盐源县",
            "513424": "德昌县",
            "513426": "会东县",
            "513427": "宁南县",
            "513428": "普格县",
            "513429": "布拖县",
            "513430": "金阳县",
            "513431": "昭觉县",
            "513432": "喜德县",
            "513433": "冕宁县",
            "513434": "越西县",
            "513435": "甘洛县",
            "513436": "美姑县",
            "513437": "雷波县",
            "520100": "贵阳市",
            "520000": "贵州省",
            "520102": "南明区",
            "520103": "云岩区",
            "520111": "花溪区",
            "520112": "乌当区",
            "520113": "白云区",
            "520115": "观山湖区",
            "520121": "开阳县",
            "520122": "息烽县",
            "520123": "修文县",
            "520181": "清镇市",
            "520200": "六盘水市",
            "520201": "钟山区",
            "520203": "六枝特区",
            "520204": "水城区",
            "520281": "盘州市",
            "520300": "遵义市",
            "520302": "红花岗区",
            "520303": "汇川区",
            "520304": "播州区",
            "520322": "桐梓县",
            "520323": "绥阳县",
            "520324": "正安县",
            "520325": "道真仡佬族苗族自治县",
            "520326": "务川仡佬族苗族自治县",
            "520327": "凤冈县",
            "520328": "湄潭县",
            "520329": "余庆县",
            "520330": "习水县",
            "520381": "赤水市",
            "520382": "仁怀市",
            "520400": "安顺市",
            "520402": "西秀区",
            "520403": "平坝区",
            "520422": "普定县",
            "520423": "镇宁布依族苗族自治县",
            "520424": "关岭布依族苗族自治县",
            "520425": "紫云苗族布依族自治县",
            "520500": "毕节市",
            "520502": "七星关区",
            "520521": "大方县",
            "520523": "金沙县",
            "520524": "织金县",
            "520525": "纳雍县",
            "520526": "威宁彝族回族苗族自治县",
            "520527": "赫章县",
            "520581": "黔西市",
            "520600": "铜仁市",
            "520602": "碧江区",
            "520603": "万山区",
            "520621": "江口县",
            "520622": "玉屏侗族自治县",
            "520623": "石阡县",
            "520624": "思南县",
            "520625": "印江土家族苗族自治县",
            "520626": "德江县",
            "520627": "沿河土家族自治县",
            "520628": "松桃苗族自治县",
            "522300": "黔西南布依族苗族自治州",
            "522301": "兴义市",
            "522302": "兴仁市",
            "522323": "普安县",
            "522324": "晴隆县",
            "522325": "贞丰县",
            "522326": "望谟县",
            "522327": "册亨县",
            "522328": "安龙县",
            "522600": "黔东南苗族侗族自治州",
            "522601": "凯里市",
            "522622": "黄平县",
            "522623": "施秉县",
            "522624": "三穗县",
            "522625": "镇远县",
            "522626": "岑巩县",
            "522627": "天柱县",
            "522628": "锦屏县",
            "522629": "剑河县",
            "522630": "台江县",
            "522631": "黎平县",
            "522632": "榕江县",
            "522633": "从江县",
            "522634": "雷山县",
            "522635": "麻江县",
            "522636": "丹寨县",
            "522700": "黔南布依族苗族自治州",
            "522701": "都匀市",
            "522702": "福泉市",
            "522722": "荔波县",
            "522723": "贵定县",
            "522725": "瓮安县",
            "522726": "独山县",
            "522727": "平塘县",
            "522728": "罗甸县",
            "522729": "长顺县",
            "522730": "龙里县",
            "522731": "惠水县",
            "522732": "三都水族自治县",
            "530100": "昆明市",
            "530000": "云南省",
            "530102": "五华区",
            "530103": "盘龙区",
            "530111": "官渡区",
            "530112": "西山区",
            "530113": "东川区",
            "530114": "呈贡区",
            "530115": "晋宁区",
            "530124": "富民县",
            "530125": "宜良县",
            "530126": "石林彝族自治县",
            "530127": "嵩明县",
            "530128": "禄劝彝族苗族自治县",
            "530129": "寻甸回族彝族自治县",
            "530181": "安宁市",
            "530300": "曲靖市",
            "530302": "麒麟区",
            "530303": "沾益区",
            "530304": "马龙区",
            "530322": "陆良县",
            "530323": "师宗县",
            "530324": "罗平县",
            "530325": "富源县",
            "530326": "会泽县",
            "530381": "宣威市",
            "530400": "玉溪市",
            "530402": "红塔区",
            "530403": "江川区",
            "530423": "通海县",
            "530424": "华宁县",
            "530425": "易门县",
            "530426": "峨山彝族自治县",
            "530427": "新平彝族傣族自治县",
            "530428": "元江哈尼族彝族傣族自治县",
            "530481": "澄江市",
            "530500": "保山市",
            "530502": "隆阳区",
            "530521": "施甸县",
            "530523": "龙陵县",
            "530524": "昌宁县",
            "530581": "腾冲市",
            "530600": "昭通市",
            "530602": "昭阳区",
            "530621": "鲁甸县",
            "530622": "巧家县",
            "530623": "盐津县",
            "530624": "大关县",
            "530625": "永善县",
            "530626": "绥江县",
            "530627": "镇雄县",
            "530628": "彝良县",
            "530629": "威信县",
            "530681": "水富市",
            "530700": "丽江市",
            "530702": "古城区",
            "530721": "玉龙纳西族自治县",
            "530722": "永胜县",
            "530723": "华坪县",
            "530724": "宁蒗彝族自治县",
            "530800": "普洱市",
            "530802": "思茅区",
            "530821": "宁洱哈尼族彝族自治县",
            "530822": "墨江哈尼族自治县",
            "530823": "景东彝族自治县",
            "530824": "景谷傣族彝族自治县",
            "530825": "镇沅彝族哈尼族拉祜族自治县",
            "530826": "江城哈尼族彝族自治县",
            "530827": "孟连傣族拉祜族佤族自治县",
            "530828": "澜沧拉祜族自治县",
            "530829": "西盟佤族自治县",
            "530900": "临沧市",
            "530902": "临翔区",
            "530921": "凤庆县",
            "530922": "云县",
            "530923": "永德县",
            "530924": "镇康县",
            "530925": "双江拉祜族佤族布朗族傣族自治县",
            "530926": "耿马傣族佤族自治县",
            "530927": "沧源佤族自治县",
            "532300": "楚雄彝族自治州",
            "532301": "楚雄市",
            "532302": "禄丰市",
            "532322": "双柏县",
            "532323": "牟定县",
            "532324": "南华县",
            "532325": "姚安县",
            "532326": "大姚县",
            "532327": "永仁县",
            "532328": "元谋县",
            "532329": "武定县",
            "532500": "红河哈尼族彝族自治州",
            "532501": "个旧市",
            "532502": "开远市",
            "532503": "蒙自市",
            "532504": "弥勒市",
            "532523": "屏边苗族自治县",
            "532524": "建水县",
            "532525": "石屏县",
            "532527": "泸西县",
            "532528": "元阳县",
            "532529": "红河县",
            "532530": "金平苗族瑶族傣族自治县",
            "532531": "绿春县",
            "532532": "河口瑶族自治县",
            "532600": "文山壮族苗族自治州",
            "532601": "文山市",
            "532622": "砚山县",
            "532623": "西畴县",
            "532624": "麻栗坡县",
            "532625": "马关县",
            "532626": "丘北县",
            "532627": "广南县",
            "532628": "富宁县",
            "532800": "西双版纳傣族自治州",
            "532801": "景洪市",
            "532822": "勐海县",
            "532823": "勐腊县",
            "532900": "大理白族自治州",
            "532901": "大理市",
            "532922": "漾濞彝族自治县",
            "532923": "祥云县",
            "532924": "宾川县",
            "532925": "弥渡县",
            "532926": "南涧彝族自治县",
            "532927": "巍山彝族回族自治县",
            "532928": "永平县",
            "532929": "云龙县",
            "532930": "洱源县",
            "532931": "剑川县",
            "532932": "鹤庆县",
            "533100": "德宏傣族景颇族自治州",
            "533102": "瑞丽市",
            "533103": "芒市",
            "533122": "梁河县",
            "533123": "盈江县",
            "533124": "陇川县",
            "533300": "怒江傈僳族自治州",
            "533301": "泸水市",
            "533323": "福贡县",
            "533324": "贡山独龙族怒族自治县",
            "533325": "兰坪白族普米族自治县",
            "533400": "迪庆藏族自治州",
            "533401": "香格里拉市",
            "533422": "德钦县",
            "533423": "维西傈僳族自治县",
            "540100": "拉萨市",
            "540000": "西藏自治区",
            "540102": "城关区",
            "540103": "堆龙德庆区",
            "540104": "达孜区",
            "540121": "林周县",
            "540122": "当雄县",
            "540123": "尼木县",
            "540124": "曲水县",
            "540127": "墨竹工卡县",
            "540171": "格尔木藏青工业园区",
            "540172": "拉萨经济技术开发区",
            "540173": "西藏文化旅游创意园区",
            "540174": "达孜工业园区",
            "540200": "日喀则市",
            "540202": "桑珠孜区",
            "540221": "南木林县",
            "540222": "江孜县",
            "540223": "定日县",
            "540224": "萨迦县",
            "540225": "拉孜县",
            "540226": "昂仁县",
            "540227": "谢通门县",
            "540228": "白朗县",
            "540229": "仁布县",
            "540230": "康马县",
            "540231": "定结县",
            "540232": "仲巴县",
            "540233": "亚东县",
            "540234": "吉隆县",
            "540235": "聂拉木县",
            "540236": "萨嘎县",
            "540237": "岗巴县",
            "540300": "昌都市",
            "540302": "卡若区",
            "540321": "江达县",
            "540322": "贡觉县",
            "540323": "类乌齐县",
            "540324": "丁青县",
            "540325": "察雅县",
            "540326": "八宿县",
            "540327": "左贡县",
            "540328": "芒康县",
            "540329": "洛隆县",
            "540330": "边坝县",
            "540400": "林芝市",
            "540402": "巴宜区",
            "540421": "工布江达县",
            "540422": "米林县",
            "540423": "墨脱县",
            "540424": "波密县",
            "540425": "察隅县",
            "540426": "朗县",
            "540500": "山南市",
            "540502": "乃东区",
            "540521": "扎囊县",
            "540522": "贡嘎县",
            "540523": "桑日县",
            "540524": "琼结县",
            "540525": "曲松县",
            "540526": "措美县",
            "540527": "洛扎县",
            "540528": "加查县",
            "540529": "隆子县",
            "540530": "错那县",
            "540531": "浪卡子县",
            "540600": "那曲市",
            "540602": "色尼区",
            "540621": "嘉黎县",
            "540622": "比如县",
            "540623": "聂荣县",
            "540624": "安多县",
            "540625": "申扎县",
            "540626": "索县",
            "540627": "班戈县",
            "540628": "巴青县",
            "540629": "尼玛县",
            "540630": "双湖县",
            "542500": "阿里地区",
            "542521": "普兰县",
            "542522": "札达县",
            "542523": "噶尔县",
            "542524": "日土县",
            "542525": "革吉县",
            "542526": "改则县",
            "542527": "措勤县",
            "610100": "西安市",
            "610000": "陕西省",
            "610102": "新城区",
            "610103": "碑林区",
            "610104": "莲湖区",
            "610111": "灞桥区",
            "610112": "未央区",
            "610113": "雁塔区",
            "610114": "阎良区",
            "610115": "临潼区",
            "610116": "长安区",
            "610117": "高陵区",
            "610118": "鄠邑区",
            "610122": "蓝田县",
            "610124": "周至县",
            "610200": "铜川市",
            "610202": "王益区",
            "610203": "印台区",
            "610204": "耀州区",
            "610222": "宜君县",
            "610300": "宝鸡市",
            "610302": "渭滨区",
            "610303": "金台区",
            "610304": "陈仓区",
            "610305": "凤翔区",
            "610323": "岐山县",
            "610324": "扶风县",
            "610326": "眉县",
            "610327": "陇县",
            "610328": "千阳县",
            "610329": "麟游县",
            "610330": "凤县",
            "610331": "太白县",
            "610400": "咸阳市",
            "610402": "秦都区",
            "610403": "杨陵区",
            "610404": "渭城区",
            "610422": "三原县",
            "610423": "泾阳县",
            "610424": "乾县",
            "610425": "礼泉县",
            "610426": "永寿县",
            "610428": "长武县",
            "610429": "旬邑县",
            "610430": "淳化县",
            "610431": "武功县",
            "610481": "兴平市",
            "610482": "彬州市",
            "610500": "渭南市",
            "610502": "临渭区",
            "610503": "华州区",
            "610522": "潼关县",
            "610523": "大荔县",
            "610524": "合阳县",
            "610525": "澄城县",
            "610526": "蒲城县",
            "610527": "白水县",
            "610528": "富平县",
            "610581": "韩城市",
            "610582": "华阴市",
            "610600": "延安市",
            "610602": "宝塔区",
            "610603": "安塞区",
            "610621": "延长县",
            "610622": "延川县",
            "610625": "志丹县",
            "610626": "吴起县",
            "610627": "甘泉县",
            "610628": "富县",
            "610629": "洛川县",
            "610630": "宜川县",
            "610631": "黄龙县",
            "610632": "黄陵县",
            "610681": "子长市",
            "610700": "汉中市",
            "610702": "汉台区",
            "610703": "南郑区",
            "610722": "城固县",
            "610723": "洋县",
            "610724": "西乡县",
            "610725": "勉县",
            "610726": "宁强县",
            "610727": "略阳县",
            "610728": "镇巴县",
            "610729": "留坝县",
            "610730": "佛坪县",
            "610800": "榆林市",
            "610802": "榆阳区",
            "610803": "横山区",
            "610822": "府谷县",
            "610824": "靖边县",
            "610825": "定边县",
            "610826": "绥德县",
            "610827": "米脂县",
            "610828": "佳县",
            "610829": "吴堡县",
            "610830": "清涧县",
            "610831": "子洲县",
            "610881": "神木市",
            "610900": "安康市",
            "610902": "汉滨区",
            "610921": "汉阴县",
            "610922": "石泉县",
            "610923": "宁陕县",
            "610924": "紫阳县",
            "610925": "岚皋县",
            "610926": "平利县",
            "610927": "镇坪县",
            "610929": "白河县",
            "610981": "旬阳市",
            "611000": "商洛市",
            "611002": "商州区",
            "611021": "洛南县",
            "611022": "丹凤县",
            "611023": "商南县",
            "611024": "山阳县",
            "611025": "镇安县",
            "611026": "柞水县",
            "620100": "兰州市",
            "620000": "甘肃省",
            "620102": "城关区",
            "620103": "七里河区",
            "620104": "西固区",
            "620105": "安宁区",
            "620111": "红古区",
            "620121": "永登县",
            "620122": "皋兰县",
            "620123": "榆中县",
            "620171": "兰州新区",
            "620200": "嘉峪关市",
            "620300": "金昌市",
            "620302": "金川区",
            "620321": "永昌县",
            "620400": "白银市",
            "620402": "白银区",
            "620403": "平川区",
            "620421": "靖远县",
            "620422": "会宁县",
            "620423": "景泰县",
            "620500": "天水市",
            "620502": "秦州区",
            "620503": "麦积区",
            "620521": "清水县",
            "620522": "秦安县",
            "620523": "甘谷县",
            "620524": "武山县",
            "620525": "张家川回族自治县",
            "620600": "武威市",
            "620602": "凉州区",
            "620621": "民勤县",
            "620622": "古浪县",
            "620623": "天祝藏族自治县",
            "620700": "张掖市",
            "620702": "甘州区",
            "620721": "肃南裕固族自治县",
            "620722": "民乐县",
            "620723": "临泽县",
            "620724": "高台县",
            "620725": "山丹县",
            "620800": "平凉市",
            "620802": "崆峒区",
            "620821": "泾川县",
            "620822": "灵台县",
            "620823": "崇信县",
            "620825": "庄浪县",
            "620826": "静宁县",
            "620881": "华亭市",
            "620900": "酒泉市",
            "620902": "肃州区",
            "620921": "金塔县",
            "620922": "瓜州县",
            "620923": "肃北蒙古族自治县",
            "620924": "阿克塞哈萨克族自治县",
            "620981": "玉门市",
            "620982": "敦煌市",
            "621000": "庆阳市",
            "621002": "西峰区",
            "621021": "庆城县",
            "621022": "环县",
            "621023": "华池县",
            "621024": "合水县",
            "621025": "正宁县",
            "621026": "宁县",
            "621027": "镇原县",
            "621100": "定西市",
            "621102": "安定区",
            "621121": "通渭县",
            "621122": "陇西县",
            "621123": "渭源县",
            "621124": "临洮县",
            "621125": "漳县",
            "621126": "岷县",
            "621200": "陇南市",
            "621202": "武都区",
            "621221": "成县",
            "621222": "文县",
            "621223": "宕昌县",
            "621224": "康县",
            "621225": "西和县",
            "621226": "礼县",
            "621227": "徽县",
            "621228": "两当县",
            "622900": "临夏回族自治州",
            "622901": "临夏市",
            "622921": "临夏县",
            "622922": "康乐县",
            "622923": "永靖县",
            "622924": "广河县",
            "622925": "和政县",
            "622926": "东乡族自治县",
            "622927": "积石山保安族东乡族撒拉族自治县",
            "623000": "甘南藏族自治州",
            "623001": "合作市",
            "623021": "临潭县",
            "623022": "卓尼县",
            "623023": "舟曲县",
            "623024": "迭部县",
            "623025": "玛曲县",
            "623026": "碌曲县",
            "623027": "夏河县",
            "630100": "西宁市",
            "630000": "青海省",
            "630102": "城东区",
            "630103": "城中区",
            "630104": "城西区",
            "630105": "城北区",
            "630106": "湟中区",
            "630121": "大通回族土族自治县",
            "630123": "湟源县",
            "630200": "海东市",
            "630202": "乐都区",
            "630203": "平安区",
            "630222": "民和回族土族自治县",
            "630223": "互助土族自治县",
            "630224": "化隆回族自治县",
            "630225": "循化撒拉族自治县",
            "632200": "海北藏族自治州",
            "632221": "门源回族自治县",
            "632222": "祁连县",
            "632223": "海晏县",
            "632224": "刚察县",
            "632300": "黄南藏族自治州",
            "632301": "同仁市",
            "632322": "尖扎县",
            "632323": "泽库县",
            "632324": "河南蒙古族自治县",
            "632500": "海南藏族自治州",
            "632521": "共和县",
            "632522": "同德县",
            "632523": "贵德县",
            "632524": "兴海县",
            "632525": "贵南县",
            "632600": "果洛藏族自治州",
            "632621": "玛沁县",
            "632622": "班玛县",
            "632623": "甘德县",
            "632624": "达日县",
            "632625": "久治县",
            "632626": "玛多县",
            "632700": "玉树藏族自治州",
            "632701": "玉树市",
            "632722": "杂多县",
            "632723": "称多县",
            "632724": "治多县",
            "632725": "囊谦县",
            "632726": "曲麻莱县",
            "632800": "海西蒙古族藏族自治州",
            "632801": "格尔木市",
            "632802": "德令哈市",
            "632803": "茫崖市",
            "632821": "乌兰县",
            "632822": "都兰县",
            "632823": "天峻县",
            "632857": "大柴旦行政委员会",
            "640100": "银川市",
            "640000": "宁夏回族自治区",
            "640104": "兴庆区",
            "640105": "西夏区",
            "640106": "金凤区",
            "640121": "永宁县",
            "640122": "贺兰县",
            "640181": "灵武市",
            "640200": "石嘴山市",
            "640202": "大武口区",
            "640205": "惠农区",
            "640221": "平罗县",
            "640300": "吴忠市",
            "640302": "利通区",
            "640303": "红寺堡区",
            "640323": "盐池县",
            "640324": "同心县",
            "640381": "青铜峡市",
            "640400": "固原市",
            "640402": "原州区",
            "640422": "西吉县",
            "640423": "隆德县",
            "640424": "泾源县",
            "640425": "彭阳县",
            "640500": "中卫市",
            "640502": "沙坡头区",
            "640521": "中宁县",
            "640522": "海原县",
            "650100": "乌鲁木齐市",
            "650000": "新疆维吾尔自治区",
            "650102": "天山区",
            "650103": "沙依巴克区",
            "650104": "新市区",
            "650105": "水磨沟区",
            "650106": "头屯河区",
            "650107": "达坂城区",
            "650109": "米东区",
            "650121": "乌鲁木齐县",
            "650200": "克拉玛依市",
            "650202": "独山子区",
            "650203": "克拉玛依区",
            "650204": "白碱滩区",
            "650205": "乌尔禾区",
            "650400": "吐鲁番市",
            "650402": "高昌区",
            "650421": "鄯善县",
            "650422": "托克逊县",
            "650500": "哈密市",
            "650502": "伊州区",
            "650521": "巴里坤哈萨克自治县",
            "650522": "伊吾县",
            "652300": "昌吉回族自治州",
            "652301": "昌吉市",
            "652302": "阜康市",
            "652323": "呼图壁县",
            "652324": "玛纳斯县",
            "652325": "奇台县",
            "652327": "吉木萨尔县",
            "652328": "木垒哈萨克自治县",
            "652700": "博尔塔拉蒙古自治州",
            "652701": "博乐市",
            "652702": "阿拉山口市",
            "652722": "精河县",
            "652723": "温泉县",
            "652800": "巴音郭楞蒙古自治州",
            "652801": "库尔勒市",
            "652822": "轮台县",
            "652823": "尉犁县",
            "652824": "若羌县",
            "652825": "且末县",
            "652826": "焉耆回族自治县",
            "652827": "和静县",
            "652828": "和硕县",
            "652829": "博湖县",
            "652871": "库尔勒经济技术开发区",
            "652900": "阿克苏地区",
            "652901": "阿克苏市",
            "652902": "库车市",
            "652922": "温宿县",
            "652924": "沙雅县",
            "652925": "新和县",
            "652926": "拜城县",
            "652927": "乌什县",
            "652928": "阿瓦提县",
            "652929": "柯坪县",
            "653000": "克孜勒苏柯尔克孜自治州",
            "653001": "阿图什市",
            "653022": "阿克陶县",
            "653023": "阿合奇县",
            "653024": "乌恰县",
            "653100": "喀什地区",
            "653101": "喀什市",
            "653121": "疏附县",
            "653122": "疏勒县",
            "653123": "英吉沙县",
            "653124": "泽普县",
            "653125": "莎车县",
            "653126": "叶城县",
            "653127": "麦盖提县",
            "653128": "岳普湖县",
            "653129": "伽师县",
            "653130": "巴楚县",
            "653131": "塔什库尔干塔吉克自治县",
            "653200": "和田地区",
            "653201": "和田市",
            "653221": "和田县",
            "653222": "墨玉县",
            "653223": "皮山县",
            "653224": "洛浦县",
            "653225": "策勒县",
            "653226": "于田县",
            "653227": "民丰县",
            "654000": "伊犁哈萨克自治州",
            "654002": "伊宁市",
            "654003": "奎屯市",
            "654004": "霍尔果斯市",
            "654021": "伊宁县",
            "654022": "察布查尔锡伯自治县",
            "654023": "霍城县",
            "654024": "巩留县",
            "654025": "新源县",
            "654026": "昭苏县",
            "654027": "特克斯县",
            "654028": "尼勒克县",
            "654200": "塔城地区",
            "654201": "塔城市",
            "654202": "乌苏市",
            "654203": "沙湾市",
            "654221": "额敏县",
            "654224": "托里县",
            "654225": "裕民县",
            "654226": "和布克赛尔蒙古自治县",
            "654300": "阿勒泰地区",
            "654301": "阿勒泰市",
            "654321": "布尔津县",
            "654322": "富蕴县",
            "654323": "福海县",
            "654324": "哈巴河县",
            "654325": "青河县",
            "654326": "吉木乃县",
            "659001": "石河子市",
            "659002": "阿拉尔市",
            "659003": "图木舒克市",
            "659004": "五家渠市",
            "659005": "北屯市",
            "659006": "铁门关市",
            "659007": "双河市",
            "659008": "可克达拉市",
            "659009": "昆玉市",
            "659010": "胡杨河市",
            "659011": "新星市",
            "710000": "台湾省",
            "810000": "香港特别行政区",
            "820000": "澳门特别行政区"
        }
        self.__data_code = list(self.__data_map.keys())


    def randomAddress(self) -> tuple:
        area = self.randomArea()
        areaCode = area[0]
        areaName = area[1]
        provinceCode = f"{areaCode[0:2]}0000"
        cityCode = f"{areaCode[0:4]}00"
        cityName = self.__data_map.get(cityCode) or self.__data_map.get(provinceCode)
        provinceName = self.__data_map.get(provinceCode) or self.__data_map.get(cityCode)
        return (provinceName, cityName, areaName)


    def randomAddressStr(self,address: str = ''):
        return f"{''.join(self.randomAddress())}{address}"


    def randomProvince(self) -> tuple:
        size = len(self.__data_code)
        import random
        codeIndex = random.randint(0, size)
        code = self.__data_code[codeIndex]
        provinceCode = f"{code[0:2]}0000"
        provinceName = self.__data_map.get(provinceCode) or self.randomProvince()[1]
        return (provinceCode, provinceName)


    def randomCity(self) -> tuple:
        size = len(self.__data_code)
        import random
        codeIndex = random.randint(0, size)
        code = self.__data_code[codeIndex]
        cityCode = f"{code[0:4]}00"
        cityName = self.__data_map.get(cityCode) or self.randomCity()[1]
        return (cityCode, cityName)


    def randomArea(self):
        size = len(self.__data_code)
        import random
        codeIndex = random.randint(0, size)
        areaCode = self.__data_code[codeIndex]
        areaName = self.__data_map.get(areaCode)
        return (areaCode, areaName)


__area_creator = AreaCreator()

def randomAddress() -> tuple:
    return __area_creator.randomAddress()


def randomAddressStr(address: str = ''):
    return __area_creator.randomAddressStr(address=address)


def randomProvince() -> tuple:
    return __area_creator.randomProvince()


def randomCity() -> tuple:
    return __area_creator.randomCity()


def randomArea():
    return __area_creator.randomArea()

def randomProvinceCode() -> str:
    return randomProvince()[0]


def randomProvinceName() -> str:
    return randomProvince()[1]


def randomCityCode() -> str:
    return randomCity()[0]


def randomCityName() -> str:
    return randomCity()[1]


def randomAreaCode() -> str:
    return randomArea()[0]


def randomAreaName() -> str:
    return randomArea()[1]
